# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`postfix`](#postfix): Manage Postfix.
* [`postfix::config`](#postfixconfig)
* [`postfix::install`](#postfixinstall)
* [`postfix::service`](#postfixservice)

### Defined types

* [`postfix::lookup::database`](#postfixlookupdatabase): Define lookup tables using static database files.
* [`postfix::lookup::ldap`](#postfixlookupldap): Define an LDAP lookup table.
* [`postfix::lookup::memcache`](#postfixlookupmemcache): Define a Memcache lookup table.
* [`postfix::lookup::mysql`](#postfixlookupmysql): Define a MySQL lookup table.
* [`postfix::lookup::pgsql`](#postfixlookuppgsql): Define a PostgreSQL lookup table.
* [`postfix::lookup::sqlite`](#postfixlookupsqlite): Define an SQLite lookup table.
* [`postfix::main`](#postfixmain): Define additional Postfix settings.  Any settings not (yet) implemented in the main class or per-transport settings can be defined here.
* [`postfix::master`](#postfixmaster): Define additional Postfix services.

### Resource types

* [`postfix_main`](#postfix_main): Manages Postfix settings.  The resource name can be used as a shortcut for specifying the setting parameter.
* [`postfix_master`](#postfix_master): Manages Postfix services.  The resource name can be used as a shortcut for specifying the service and type parameters by using the form `<ser

### Functions

* [`postfix::flatten_host`](#postfixflatten_host): Flatten a host structure to a string.
* [`postfix::flatten_hosts`](#postfixflatten_hosts): Flatten an array of host structures to an array of strings.

### Data types

* [`Postfix::Type::Lookup`](#postfixtypelookup)
* [`Postfix::Type::Lookup::Database`](#postfixtypelookupdatabase)
* [`Postfix::Type::Lookup::Database::Flat`](#postfixtypelookupdatabaseflat)
* [`Postfix::Type::Lookup::Database::Hashed`](#postfixtypelookupdatabasehashed)
* [`Postfix::Type::Lookup::LDAP::Host`](#postfixtypelookupldaphost)
* [`Postfix::Type::Lookup::Memcache::Host`](#postfixtypelookupmemcachehost)
* [`Postfix::Type::Lookup::MySQL::Host`](#postfixtypelookupmysqlhost)
* [`Postfix::Type::Lookup::PgSQL::Host`](#postfixtypelookuppgsqlhost)

## Classes

### <a name="postfix"></a>`postfix`

Manage Postfix.

* **Since** 1.0.0

* **See also**
  * puppet_defined_types::postfix::main
    * postfix::main
  * puppet_defined_types::postfix::master
    * postfix::master
  * puppet_defined_types::postfix::lookup::database
    * postfix::lookup::database
  * puppet_defined_types::postfix::lookup::ldap
    * postfix::lookup::ldap
  * puppet_defined_types::postfix::lookup::memcache
    * postfix::lookup::memcache
  * puppet_defined_types::postfix::lookup::mysql
    * postfix::lookup::mysql
  * puppet_defined_types::postfix::lookup::pgsql
    * postfix::lookup::pgsql
  * puppet_defined_types::postfix::lookup::sqlite
    * postfix::lookup::sqlite

#### Examples

##### Configure Postfix with the defaults as shipped by the OS and managing any aliases using the standard Puppet `mailalias` resource type

```puppet
include postfix

postfix::lookup::database { '/etc/aliases':
  type => 'hash',
}

Mailalias <||> -> Postfix::Lookup::Database['/etc/aliases']
```

##### Configure Postfix with an additional submission service running on TCP port 587

```puppet
include postfix

postfix::master { 'submission/inet':
  private => 'n',
  chroot  => 'n',
  command => 'smtpd -o smtpd_tls_security_level=encrypt -o smtpd_recipient_restrictions=permit_sasl_authenticated,reject',
}
```

##### Configure Postfix for virtual mailbox hosting using LDAP to provide the various lookup tables

```puppet
class { 'postfix':
  virtual_mailbox_base    => '/var/mail/vhosts',
  virtual_mailbox_domains => ['ldap:/etc/postfix/virtualdomains.cf'],
  virtual_mailbox_maps    => ['ldap:/etc/postfix/virtualrecipients.cf'],
  virtual_minimum_uid     => 100,
  virtual_uid_maps        => 'static:5000',
  virtual_gid_maps        => 'static:5000',
}

# Specify connection defaults to enable sharing as per LDAP_README
Postfix::Lookup::Ldap {
  server_host => ['ldap://192.0.2.1'],
  search_base => 'dc=example,dc=com',
  bind_dn     => 'cn=Manager,dc=example,dc=com',
  bind_pw     => 'secret',
  version     => 3,
}

postfix::lookup::ldap { '/etc/postfix/virtualdomains.cf':
  query_filter     => '(associatedDomain=%s)',
  result_attribute => ['associatedDomain'],
}

postfix::lookup::ldap { '/etc/postfix/virtualrecipients.cf':
  query_filter     => '(mail=%s)',
  result_attribute => ['mail'],
}
```

#### Parameters

The following parameters are available in the `postfix` class:

* [`conf_dir`](#conf_dir)
* [`services`](#services)
* [`lookup_packages`](#lookup_packages)
* [`package_name`](#package_name)
* [`service_name`](#service_name)
* [`twobounce_notice_recipient`](#twobounce_notice_recipient)
* [`access_map_defer_code`](#access_map_defer_code)
* [`access_map_reject_code`](#access_map_reject_code)
* [`address_verify_cache_cleanup_interval`](#address_verify_cache_cleanup_interval)
* [`address_verify_default_transport`](#address_verify_default_transport)
* [`address_verify_local_transport`](#address_verify_local_transport)
* [`address_verify_map`](#address_verify_map)
* [`address_verify_negative_cache`](#address_verify_negative_cache)
* [`address_verify_negative_expire_time`](#address_verify_negative_expire_time)
* [`address_verify_negative_refresh_time`](#address_verify_negative_refresh_time)
* [`address_verify_poll_count`](#address_verify_poll_count)
* [`address_verify_poll_delay`](#address_verify_poll_delay)
* [`address_verify_positive_expire_time`](#address_verify_positive_expire_time)
* [`address_verify_positive_refresh_time`](#address_verify_positive_refresh_time)
* [`address_verify_relay_transport`](#address_verify_relay_transport)
* [`address_verify_relayhost`](#address_verify_relayhost)
* [`address_verify_sender`](#address_verify_sender)
* [`address_verify_sender_dependent_default_transport_maps`](#address_verify_sender_dependent_default_transport_maps)
* [`address_verify_sender_dependent_relayhost_maps`](#address_verify_sender_dependent_relayhost_maps)
* [`address_verify_sender_ttl`](#address_verify_sender_ttl)
* [`address_verify_service_name`](#address_verify_service_name)
* [`address_verify_transport_maps`](#address_verify_transport_maps)
* [`address_verify_virtual_transport`](#address_verify_virtual_transport)
* [`alias_database`](#alias_database)
* [`alias_maps`](#alias_maps)
* [`allow_mail_to_commands`](#allow_mail_to_commands)
* [`allow_mail_to_files`](#allow_mail_to_files)
* [`allow_min_user`](#allow_min_user)
* [`allow_percent_hack`](#allow_percent_hack)
* [`allow_untrusted_routing`](#allow_untrusted_routing)
* [`alternate_config_directories`](#alternate_config_directories)
* [`always_add_missing_headers`](#always_add_missing_headers)
* [`always_bcc`](#always_bcc)
* [`anvil_rate_time_unit`](#anvil_rate_time_unit)
* [`anvil_status_update_time`](#anvil_status_update_time)
* [`append_at_myorigin`](#append_at_myorigin)
* [`append_dot_mydomain`](#append_dot_mydomain)
* [`application_event_drain_time`](#application_event_drain_time)
* [`authorized_flush_users`](#authorized_flush_users)
* [`authorized_mailq_users`](#authorized_mailq_users)
* [`authorized_submit_users`](#authorized_submit_users)
* [`backwards_bounce_logfile_compatibility`](#backwards_bounce_logfile_compatibility)
* [`berkeley_db_create_buffer_size`](#berkeley_db_create_buffer_size)
* [`berkeley_db_read_buffer_size`](#berkeley_db_read_buffer_size)
* [`best_mx_transport`](#best_mx_transport)
* [`biff`](#biff)
* [`body_checks`](#body_checks)
* [`body_checks_size_limit`](#body_checks_size_limit)
* [`bounce_notice_recipient`](#bounce_notice_recipient)
* [`bounce_queue_lifetime`](#bounce_queue_lifetime)
* [`bounce_service_name`](#bounce_service_name)
* [`bounce_size_limit`](#bounce_size_limit)
* [`bounce_template_file`](#bounce_template_file)
* [`broken_sasl_auth_clients`](#broken_sasl_auth_clients)
* [`canonical_classes`](#canonical_classes)
* [`canonical_maps`](#canonical_maps)
* [`cleanup_service_name`](#cleanup_service_name)
* [`command_directory`](#command_directory)
* [`command_execution_directory`](#command_execution_directory)
* [`command_expansion_filter`](#command_expansion_filter)
* [`command_time_limit`](#command_time_limit)
* [`compatibility_level`](#compatibility_level)
* [`config_directory`](#config_directory)
* [`connection_cache_protocol_timeout`](#connection_cache_protocol_timeout)
* [`connection_cache_service_name`](#connection_cache_service_name)
* [`connection_cache_status_update_time`](#connection_cache_status_update_time)
* [`connection_cache_ttl_limit`](#connection_cache_ttl_limit)
* [`content_filter`](#content_filter)
* [`cyrus_sasl_config_path`](#cyrus_sasl_config_path)
* [`daemon_directory`](#daemon_directory)
* [`daemon_table_open_error_is_fatal`](#daemon_table_open_error_is_fatal)
* [`daemon_timeout`](#daemon_timeout)
* [`data_directory`](#data_directory)
* [`debug_peer_level`](#debug_peer_level)
* [`debug_peer_list`](#debug_peer_list)
* [`debugger_command`](#debugger_command)
* [`default_database_type`](#default_database_type)
* [`default_delivery_slot_cost`](#default_delivery_slot_cost)
* [`default_delivery_slot_discount`](#default_delivery_slot_discount)
* [`default_delivery_slot_loan`](#default_delivery_slot_loan)
* [`default_destination_concurrency_failed_cohort_limit`](#default_destination_concurrency_failed_cohort_limit)
* [`default_destination_concurrency_limit`](#default_destination_concurrency_limit)
* [`default_destination_concurrency_negative_feedback`](#default_destination_concurrency_negative_feedback)
* [`default_destination_concurrency_positive_feedback`](#default_destination_concurrency_positive_feedback)
* [`default_destination_rate_delay`](#default_destination_rate_delay)
* [`default_destination_recipient_limit`](#default_destination_recipient_limit)
* [`default_extra_recipient_limit`](#default_extra_recipient_limit)
* [`default_filter_nexthop`](#default_filter_nexthop)
* [`default_minimum_delivery_slots`](#default_minimum_delivery_slots)
* [`default_privs`](#default_privs)
* [`default_process_limit`](#default_process_limit)
* [`default_rbl_reply`](#default_rbl_reply)
* [`default_recipient_limit`](#default_recipient_limit)
* [`default_recipient_refill_delay`](#default_recipient_refill_delay)
* [`default_recipient_refill_limit`](#default_recipient_refill_limit)
* [`default_transport`](#default_transport)
* [`default_verp_delimiters`](#default_verp_delimiters)
* [`defer_code`](#defer_code)
* [`defer_service_name`](#defer_service_name)
* [`defer_transports`](#defer_transports)
* [`delay_logging_resolution_limit`](#delay_logging_resolution_limit)
* [`delay_notice_recipient`](#delay_notice_recipient)
* [`delay_warning_time`](#delay_warning_time)
* [`deliver_lock_attempts`](#deliver_lock_attempts)
* [`deliver_lock_delay`](#deliver_lock_delay)
* [`destination_concurrency_feedback_debug`](#destination_concurrency_feedback_debug)
* [`detect_8bit_encoding_header`](#detect_8bit_encoding_header)
* [`disable_dns_lookups`](#disable_dns_lookups)
* [`disable_mime_input_processing`](#disable_mime_input_processing)
* [`disable_mime_output_conversion`](#disable_mime_output_conversion)
* [`disable_verp_bounces`](#disable_verp_bounces)
* [`disable_vrfy_command`](#disable_vrfy_command)
* [`dnsblog_reply_delay`](#dnsblog_reply_delay)
* [`dnsblog_service_name`](#dnsblog_service_name)
* [`dont_remove`](#dont_remove)
* [`double_bounce_sender`](#double_bounce_sender)
* [`duplicate_filter_limit`](#duplicate_filter_limit)
* [`empty_address_default_transport_maps_lookup_key`](#empty_address_default_transport_maps_lookup_key)
* [`empty_address_recipient`](#empty_address_recipient)
* [`empty_address_relayhost_maps_lookup_key`](#empty_address_relayhost_maps_lookup_key)
* [`enable_long_queue_ids`](#enable_long_queue_ids)
* [`enable_original_recipient`](#enable_original_recipient)
* [`error_notice_recipient`](#error_notice_recipient)
* [`error_service_name`](#error_service_name)
* [`execution_directory_expansion_filter`](#execution_directory_expansion_filter)
* [`expand_owner_alias`](#expand_owner_alias)
* [`export_environment`](#export_environment)
* [`fallback_transport`](#fallback_transport)
* [`fallback_transport_maps`](#fallback_transport_maps)
* [`fast_flush_domains`](#fast_flush_domains)
* [`fast_flush_purge_time`](#fast_flush_purge_time)
* [`fast_flush_refresh_time`](#fast_flush_refresh_time)
* [`fault_injection_code`](#fault_injection_code)
* [`flush_service_name`](#flush_service_name)
* [`fork_attempts`](#fork_attempts)
* [`fork_delay`](#fork_delay)
* [`forward_expansion_filter`](#forward_expansion_filter)
* [`forward_path`](#forward_path)
* [`frozen_delivered_to`](#frozen_delivered_to)
* [`hash_queue_depth`](#hash_queue_depth)
* [`hash_queue_names`](#hash_queue_names)
* [`header_address_token_limit`](#header_address_token_limit)
* [`header_checks`](#header_checks)
* [`header_size_limit`](#header_size_limit)
* [`helpful_warnings`](#helpful_warnings)
* [`home_mailbox`](#home_mailbox)
* [`hopcount_limit`](#hopcount_limit)
* [`html_directory`](#html_directory)
* [`ignore_mx_lookup_error`](#ignore_mx_lookup_error)
* [`import_environment`](#import_environment)
* [`in_flow_delay`](#in_flow_delay)
* [`inet_interfaces`](#inet_interfaces)
* [`inet_protocols`](#inet_protocols)
* [`initial_destination_concurrency`](#initial_destination_concurrency)
* [`internal_mail_filter_classes`](#internal_mail_filter_classes)
* [`invalid_hostname_reject_code`](#invalid_hostname_reject_code)
* [`ipc_idle`](#ipc_idle)
* [`ipc_timeout`](#ipc_timeout)
* [`ipc_ttl`](#ipc_ttl)
* [`line_length_limit`](#line_length_limit)
* [`lmtp_address_preference`](#lmtp_address_preference)
* [`lmtp_assume_final`](#lmtp_assume_final)
* [`lmtp_bind_address`](#lmtp_bind_address)
* [`lmtp_bind_address6`](#lmtp_bind_address6)
* [`lmtp_body_checks`](#lmtp_body_checks)
* [`lmtp_cname_overrides_servername`](#lmtp_cname_overrides_servername)
* [`lmtp_connect_timeout`](#lmtp_connect_timeout)
* [`lmtp_connection_cache_destinations`](#lmtp_connection_cache_destinations)
* [`lmtp_connection_cache_on_demand`](#lmtp_connection_cache_on_demand)
* [`lmtp_connection_cache_time_limit`](#lmtp_connection_cache_time_limit)
* [`lmtp_connection_reuse_time_limit`](#lmtp_connection_reuse_time_limit)
* [`lmtp_data_done_timeout`](#lmtp_data_done_timeout)
* [`lmtp_data_init_timeout`](#lmtp_data_init_timeout)
* [`lmtp_data_xfer_timeout`](#lmtp_data_xfer_timeout)
* [`lmtp_defer_if_no_mx_address_found`](#lmtp_defer_if_no_mx_address_found)
* [`lmtp_discard_lhlo_keyword_address_maps`](#lmtp_discard_lhlo_keyword_address_maps)
* [`lmtp_discard_lhlo_keywords`](#lmtp_discard_lhlo_keywords)
* [`lmtp_dns_resolver_options`](#lmtp_dns_resolver_options)
* [`lmtp_enforce_tls`](#lmtp_enforce_tls)
* [`lmtp_generic_maps`](#lmtp_generic_maps)
* [`lmtp_header_checks`](#lmtp_header_checks)
* [`lmtp_host_lookup`](#lmtp_host_lookup)
* [`lmtp_lhlo_name`](#lmtp_lhlo_name)
* [`lmtp_lhlo_timeout`](#lmtp_lhlo_timeout)
* [`lmtp_line_length_limit`](#lmtp_line_length_limit)
* [`lmtp_mail_timeout`](#lmtp_mail_timeout)
* [`lmtp_mime_header_checks`](#lmtp_mime_header_checks)
* [`lmtp_mx_address_limit`](#lmtp_mx_address_limit)
* [`lmtp_mx_session_limit`](#lmtp_mx_session_limit)
* [`lmtp_nested_header_checks`](#lmtp_nested_header_checks)
* [`lmtp_per_record_deadline`](#lmtp_per_record_deadline)
* [`lmtp_pix_workaround_delay_time`](#lmtp_pix_workaround_delay_time)
* [`lmtp_pix_workaround_maps`](#lmtp_pix_workaround_maps)
* [`lmtp_pix_workaround_threshold_time`](#lmtp_pix_workaround_threshold_time)
* [`lmtp_pix_workarounds`](#lmtp_pix_workarounds)
* [`lmtp_quit_timeout`](#lmtp_quit_timeout)
* [`lmtp_quote_rfc821_envelope`](#lmtp_quote_rfc821_envelope)
* [`lmtp_randomize_addresses`](#lmtp_randomize_addresses)
* [`lmtp_rcpt_timeout`](#lmtp_rcpt_timeout)
* [`lmtp_reply_filter`](#lmtp_reply_filter)
* [`lmtp_rset_timeout`](#lmtp_rset_timeout)
* [`lmtp_sasl_auth_cache_name`](#lmtp_sasl_auth_cache_name)
* [`lmtp_sasl_auth_cache_time`](#lmtp_sasl_auth_cache_time)
* [`lmtp_sasl_auth_enable`](#lmtp_sasl_auth_enable)
* [`lmtp_sasl_auth_soft_bounce`](#lmtp_sasl_auth_soft_bounce)
* [`lmtp_sasl_mechanism_filter`](#lmtp_sasl_mechanism_filter)
* [`lmtp_sasl_password_maps`](#lmtp_sasl_password_maps)
* [`lmtp_sasl_path`](#lmtp_sasl_path)
* [`lmtp_sasl_security_options`](#lmtp_sasl_security_options)
* [`lmtp_sasl_tls_security_options`](#lmtp_sasl_tls_security_options)
* [`lmtp_sasl_tls_verified_security_options`](#lmtp_sasl_tls_verified_security_options)
* [`lmtp_sasl_type`](#lmtp_sasl_type)
* [`lmtp_send_dummy_mail_auth`](#lmtp_send_dummy_mail_auth)
* [`lmtp_send_xforward_command`](#lmtp_send_xforward_command)
* [`lmtp_sender_dependent_authentication`](#lmtp_sender_dependent_authentication)
* [`lmtp_skip_5xx_greeting`](#lmtp_skip_5xx_greeting)
* [`lmtp_skip_quit_response`](#lmtp_skip_quit_response)
* [`lmtp_starttls_timeout`](#lmtp_starttls_timeout)
* [`lmtp_tcp_port`](#lmtp_tcp_port)
* [`lmtp_tls_cafile`](#lmtp_tls_cafile)
* [`lmtp_tls_capath`](#lmtp_tls_capath)
* [`lmtp_tls_block_early_mail_reply`](#lmtp_tls_block_early_mail_reply)
* [`lmtp_tls_cert_file`](#lmtp_tls_cert_file)
* [`lmtp_tls_ciphers`](#lmtp_tls_ciphers)
* [`lmtp_tls_dcert_file`](#lmtp_tls_dcert_file)
* [`lmtp_tls_dkey_file`](#lmtp_tls_dkey_file)
* [`lmtp_tls_eccert_file`](#lmtp_tls_eccert_file)
* [`lmtp_tls_eckey_file`](#lmtp_tls_eckey_file)
* [`lmtp_tls_enforce_peername`](#lmtp_tls_enforce_peername)
* [`lmtp_tls_exclude_ciphers`](#lmtp_tls_exclude_ciphers)
* [`lmtp_tls_fingerprint_cert_match`](#lmtp_tls_fingerprint_cert_match)
* [`lmtp_tls_fingerprint_digest`](#lmtp_tls_fingerprint_digest)
* [`lmtp_tls_key_file`](#lmtp_tls_key_file)
* [`lmtp_tls_loglevel`](#lmtp_tls_loglevel)
* [`lmtp_tls_mandatory_ciphers`](#lmtp_tls_mandatory_ciphers)
* [`lmtp_tls_mandatory_exclude_ciphers`](#lmtp_tls_mandatory_exclude_ciphers)
* [`lmtp_tls_mandatory_protocols`](#lmtp_tls_mandatory_protocols)
* [`lmtp_tls_note_starttls_offer`](#lmtp_tls_note_starttls_offer)
* [`lmtp_tls_per_site`](#lmtp_tls_per_site)
* [`lmtp_tls_policy_maps`](#lmtp_tls_policy_maps)
* [`lmtp_tls_protocols`](#lmtp_tls_protocols)
* [`lmtp_tls_scert_verifydepth`](#lmtp_tls_scert_verifydepth)
* [`lmtp_tls_secure_cert_match`](#lmtp_tls_secure_cert_match)
* [`lmtp_tls_security_level`](#lmtp_tls_security_level)
* [`lmtp_tls_session_cache_database`](#lmtp_tls_session_cache_database)
* [`lmtp_tls_session_cache_timeout`](#lmtp_tls_session_cache_timeout)
* [`lmtp_tls_verify_cert_match`](#lmtp_tls_verify_cert_match)
* [`lmtp_use_tls`](#lmtp_use_tls)
* [`lmtp_xforward_timeout`](#lmtp_xforward_timeout)
* [`local_command_shell`](#local_command_shell)
* [`local_header_rewrite_clients`](#local_header_rewrite_clients)
* [`local_recipient_maps`](#local_recipient_maps)
* [`local_transport`](#local_transport)
* [`luser_relay`](#luser_relay)
* [`mail_name`](#mail_name)
* [`mail_owner`](#mail_owner)
* [`mail_release_date`](#mail_release_date)
* [`mail_spool_directory`](#mail_spool_directory)
* [`mail_version`](#mail_version)
* [`mailbox_command`](#mailbox_command)
* [`mailbox_command_maps`](#mailbox_command_maps)
* [`mailbox_delivery_lock`](#mailbox_delivery_lock)
* [`mailbox_size_limit`](#mailbox_size_limit)
* [`mailbox_transport`](#mailbox_transport)
* [`mailbox_transport_maps`](#mailbox_transport_maps)
* [`mailq_path`](#mailq_path)
* [`manpage_directory`](#manpage_directory)
* [`maps_rbl_domains`](#maps_rbl_domains)
* [`maps_rbl_reject_code`](#maps_rbl_reject_code)
* [`masquerade_classes`](#masquerade_classes)
* [`masquerade_domains`](#masquerade_domains)
* [`masquerade_exceptions`](#masquerade_exceptions)
* [`master_service_disable`](#master_service_disable)
* [`max_idle`](#max_idle)
* [`max_use`](#max_use)
* [`maximal_backoff_time`](#maximal_backoff_time)
* [`maximal_queue_lifetime`](#maximal_queue_lifetime)
* [`message_reject_characters`](#message_reject_characters)
* [`message_size_limit`](#message_size_limit)
* [`message_strip_characters`](#message_strip_characters)
* [`meta_directory`](#meta_directory)
* [`milter_command_timeout`](#milter_command_timeout)
* [`milter_connect_macros`](#milter_connect_macros)
* [`milter_connect_timeout`](#milter_connect_timeout)
* [`milter_content_timeout`](#milter_content_timeout)
* [`milter_data_macros`](#milter_data_macros)
* [`milter_default_action`](#milter_default_action)
* [`milter_end_of_data_macros`](#milter_end_of_data_macros)
* [`milter_end_of_header_macros`](#milter_end_of_header_macros)
* [`milter_header_checks`](#milter_header_checks)
* [`milter_helo_macros`](#milter_helo_macros)
* [`milter_macro_daemon_name`](#milter_macro_daemon_name)
* [`milter_macro_v`](#milter_macro_v)
* [`milter_mail_macros`](#milter_mail_macros)
* [`milter_protocol`](#milter_protocol)
* [`milter_rcpt_macros`](#milter_rcpt_macros)
* [`milter_unknown_command_macros`](#milter_unknown_command_macros)
* [`mime_boundary_length_limit`](#mime_boundary_length_limit)
* [`mime_header_checks`](#mime_header_checks)
* [`mime_nesting_limit`](#mime_nesting_limit)
* [`minimal_backoff_time`](#minimal_backoff_time)
* [`multi_instance_directories`](#multi_instance_directories)
* [`multi_instance_enable`](#multi_instance_enable)
* [`multi_instance_group`](#multi_instance_group)
* [`multi_instance_name`](#multi_instance_name)
* [`multi_instance_wrapper`](#multi_instance_wrapper)
* [`multi_recipient_bounce_reject_code`](#multi_recipient_bounce_reject_code)
* [`mydestination`](#mydestination)
* [`mydomain`](#mydomain)
* [`myhostname`](#myhostname)
* [`mynetworks`](#mynetworks)
* [`mynetworks_style`](#mynetworks_style)
* [`myorigin`](#myorigin)
* [`nested_header_checks`](#nested_header_checks)
* [`newaliases_path`](#newaliases_path)
* [`non_fqdn_reject_code`](#non_fqdn_reject_code)
* [`non_smtpd_milters`](#non_smtpd_milters)
* [`notify_classes`](#notify_classes)
* [`owner_request_special`](#owner_request_special)
* [`parent_domain_matches_subdomains`](#parent_domain_matches_subdomains)
* [`permit_mx_backup_networks`](#permit_mx_backup_networks)
* [`pickup_service_name`](#pickup_service_name)
* [`plaintext_reject_code`](#plaintext_reject_code)
* [`postmulti_control_commands`](#postmulti_control_commands)
* [`postmulti_start_commands`](#postmulti_start_commands)
* [`postmulti_stop_commands`](#postmulti_stop_commands)
* [`postscreen_access_list`](#postscreen_access_list)
* [`postscreen_bare_newline_action`](#postscreen_bare_newline_action)
* [`postscreen_bare_newline_enable`](#postscreen_bare_newline_enable)
* [`postscreen_bare_newline_ttl`](#postscreen_bare_newline_ttl)
* [`postscreen_blacklist_action`](#postscreen_blacklist_action)
* [`postscreen_cache_cleanup_interval`](#postscreen_cache_cleanup_interval)
* [`postscreen_cache_map`](#postscreen_cache_map)
* [`postscreen_cache_retention_time`](#postscreen_cache_retention_time)
* [`postscreen_client_connection_count_limit`](#postscreen_client_connection_count_limit)
* [`postscreen_command_count_limit`](#postscreen_command_count_limit)
* [`postscreen_command_filter`](#postscreen_command_filter)
* [`postscreen_command_time_limit`](#postscreen_command_time_limit)
* [`postscreen_disable_vrfy_command`](#postscreen_disable_vrfy_command)
* [`postscreen_discard_ehlo_keyword_address_maps`](#postscreen_discard_ehlo_keyword_address_maps)
* [`postscreen_discard_ehlo_keywords`](#postscreen_discard_ehlo_keywords)
* [`postscreen_dnsbl_action`](#postscreen_dnsbl_action)
* [`postscreen_dnsbl_reply_map`](#postscreen_dnsbl_reply_map)
* [`postscreen_dnsbl_sites`](#postscreen_dnsbl_sites)
* [`postscreen_dnsbl_threshold`](#postscreen_dnsbl_threshold)
* [`postscreen_dnsbl_ttl`](#postscreen_dnsbl_ttl)
* [`postscreen_enforce_tls`](#postscreen_enforce_tls)
* [`postscreen_expansion_filter`](#postscreen_expansion_filter)
* [`postscreen_forbidden_commands`](#postscreen_forbidden_commands)
* [`postscreen_greet_action`](#postscreen_greet_action)
* [`postscreen_greet_banner`](#postscreen_greet_banner)
* [`postscreen_greet_ttl`](#postscreen_greet_ttl)
* [`postscreen_greet_wait`](#postscreen_greet_wait)
* [`postscreen_helo_required`](#postscreen_helo_required)
* [`postscreen_non_smtp_command_action`](#postscreen_non_smtp_command_action)
* [`postscreen_non_smtp_command_enable`](#postscreen_non_smtp_command_enable)
* [`postscreen_non_smtp_command_ttl`](#postscreen_non_smtp_command_ttl)
* [`postscreen_pipelining_action`](#postscreen_pipelining_action)
* [`postscreen_pipelining_enable`](#postscreen_pipelining_enable)
* [`postscreen_pipelining_ttl`](#postscreen_pipelining_ttl)
* [`postscreen_post_queue_limit`](#postscreen_post_queue_limit)
* [`postscreen_pre_queue_limit`](#postscreen_pre_queue_limit)
* [`postscreen_reject_footer`](#postscreen_reject_footer)
* [`postscreen_tls_security_level`](#postscreen_tls_security_level)
* [`postscreen_upstream_proxy_protocol`](#postscreen_upstream_proxy_protocol)
* [`postscreen_upstream_proxy_timeout`](#postscreen_upstream_proxy_timeout)
* [`postscreen_use_tls`](#postscreen_use_tls)
* [`postscreen_watchdog_timeout`](#postscreen_watchdog_timeout)
* [`postscreen_whitelist_interfaces`](#postscreen_whitelist_interfaces)
* [`prepend_delivered_header`](#prepend_delivered_header)
* [`process_id_directory`](#process_id_directory)
* [`propagate_unmatched_extensions`](#propagate_unmatched_extensions)
* [`proxy_interfaces`](#proxy_interfaces)
* [`proxy_read_maps`](#proxy_read_maps)
* [`proxy_write_maps`](#proxy_write_maps)
* [`proxymap_service_name`](#proxymap_service_name)
* [`proxywrite_service_name`](#proxywrite_service_name)
* [`qmgr_clog_warn_time`](#qmgr_clog_warn_time)
* [`qmgr_daemon_timeout`](#qmgr_daemon_timeout)
* [`qmgr_fudge_factor`](#qmgr_fudge_factor)
* [`qmgr_ipc_timeout`](#qmgr_ipc_timeout)
* [`qmgr_message_active_limit`](#qmgr_message_active_limit)
* [`qmgr_message_recipient_limit`](#qmgr_message_recipient_limit)
* [`qmgr_message_recipient_minimum`](#qmgr_message_recipient_minimum)
* [`qmqpd_authorized_clients`](#qmqpd_authorized_clients)
* [`qmqpd_client_port_logging`](#qmqpd_client_port_logging)
* [`qmqpd_error_delay`](#qmqpd_error_delay)
* [`qmqpd_timeout`](#qmqpd_timeout)
* [`queue_directory`](#queue_directory)
* [`queue_file_attribute_count_limit`](#queue_file_attribute_count_limit)
* [`queue_minfree`](#queue_minfree)
* [`queue_run_delay`](#queue_run_delay)
* [`queue_service_name`](#queue_service_name)
* [`rbl_reply_maps`](#rbl_reply_maps)
* [`readme_directory`](#readme_directory)
* [`receive_override_options`](#receive_override_options)
* [`recipient_bcc_maps`](#recipient_bcc_maps)
* [`recipient_canonical_classes`](#recipient_canonical_classes)
* [`recipient_canonical_maps`](#recipient_canonical_maps)
* [`recipient_delimiter`](#recipient_delimiter)
* [`reject_code`](#reject_code)
* [`reject_tempfail_action`](#reject_tempfail_action)
* [`relay_clientcerts`](#relay_clientcerts)
* [`relay_domains`](#relay_domains)
* [`relay_domains_reject_code`](#relay_domains_reject_code)
* [`relay_recipient_maps`](#relay_recipient_maps)
* [`relay_transport`](#relay_transport)
* [`relayhost`](#relayhost)
* [`relocated_maps`](#relocated_maps)
* [`remote_header_rewrite_domain`](#remote_header_rewrite_domain)
* [`require_home_directory`](#require_home_directory)
* [`reset_owner_alias`](#reset_owner_alias)
* [`resolve_dequoted_address`](#resolve_dequoted_address)
* [`resolve_null_domain`](#resolve_null_domain)
* [`resolve_numeric_domain`](#resolve_numeric_domain)
* [`rewrite_service_name`](#rewrite_service_name)
* [`sample_directory`](#sample_directory)
* [`send_cyrus_sasl_authzid`](#send_cyrus_sasl_authzid)
* [`sender_bcc_maps`](#sender_bcc_maps)
* [`sender_canonical_classes`](#sender_canonical_classes)
* [`sender_canonical_maps`](#sender_canonical_maps)
* [`sender_dependent_default_transport_maps`](#sender_dependent_default_transport_maps)
* [`sender_dependent_relayhost_maps`](#sender_dependent_relayhost_maps)
* [`sendmail_fix_line_endings`](#sendmail_fix_line_endings)
* [`sendmail_path`](#sendmail_path)
* [`service_throttle_time`](#service_throttle_time)
* [`setgid_group`](#setgid_group)
* [`shlib_directory`](#shlib_directory)
* [`show_user_unknown_table_name`](#show_user_unknown_table_name)
* [`showq_service_name`](#showq_service_name)
* [`smtp_address_preference`](#smtp_address_preference)
* [`smtp_always_send_ehlo`](#smtp_always_send_ehlo)
* [`smtp_bind_address`](#smtp_bind_address)
* [`smtp_bind_address6`](#smtp_bind_address6)
* [`smtp_body_checks`](#smtp_body_checks)
* [`smtp_cname_overrides_servername`](#smtp_cname_overrides_servername)
* [`smtp_connect_timeout`](#smtp_connect_timeout)
* [`smtp_connection_cache_destinations`](#smtp_connection_cache_destinations)
* [`smtp_connection_cache_on_demand`](#smtp_connection_cache_on_demand)
* [`smtp_connection_cache_time_limit`](#smtp_connection_cache_time_limit)
* [`smtp_connection_reuse_time_limit`](#smtp_connection_reuse_time_limit)
* [`smtp_data_done_timeout`](#smtp_data_done_timeout)
* [`smtp_data_init_timeout`](#smtp_data_init_timeout)
* [`smtp_data_xfer_timeout`](#smtp_data_xfer_timeout)
* [`smtp_defer_if_no_mx_address_found`](#smtp_defer_if_no_mx_address_found)
* [`smtp_discard_ehlo_keyword_address_maps`](#smtp_discard_ehlo_keyword_address_maps)
* [`smtp_discard_ehlo_keywords`](#smtp_discard_ehlo_keywords)
* [`smtp_dns_resolver_options`](#smtp_dns_resolver_options)
* [`smtp_enforce_tls`](#smtp_enforce_tls)
* [`smtp_fallback_relay`](#smtp_fallback_relay)
* [`smtp_generic_maps`](#smtp_generic_maps)
* [`smtp_header_checks`](#smtp_header_checks)
* [`smtp_helo_name`](#smtp_helo_name)
* [`smtp_helo_timeout`](#smtp_helo_timeout)
* [`smtp_host_lookup`](#smtp_host_lookup)
* [`smtp_line_length_limit`](#smtp_line_length_limit)
* [`smtp_mail_timeout`](#smtp_mail_timeout)
* [`smtp_mime_header_checks`](#smtp_mime_header_checks)
* [`smtp_mx_address_limit`](#smtp_mx_address_limit)
* [`smtp_mx_session_limit`](#smtp_mx_session_limit)
* [`smtp_nested_header_checks`](#smtp_nested_header_checks)
* [`smtp_never_send_ehlo`](#smtp_never_send_ehlo)
* [`smtp_per_record_deadline`](#smtp_per_record_deadline)
* [`smtp_pix_workaround_delay_time`](#smtp_pix_workaround_delay_time)
* [`smtp_pix_workaround_maps`](#smtp_pix_workaround_maps)
* [`smtp_pix_workaround_threshold_time`](#smtp_pix_workaround_threshold_time)
* [`smtp_pix_workarounds`](#smtp_pix_workarounds)
* [`smtp_quit_timeout`](#smtp_quit_timeout)
* [`smtp_quote_rfc821_envelope`](#smtp_quote_rfc821_envelope)
* [`smtp_randomize_addresses`](#smtp_randomize_addresses)
* [`smtp_rcpt_timeout`](#smtp_rcpt_timeout)
* [`smtp_reply_filter`](#smtp_reply_filter)
* [`smtp_rset_timeout`](#smtp_rset_timeout)
* [`smtp_sasl_auth_cache_name`](#smtp_sasl_auth_cache_name)
* [`smtp_sasl_auth_cache_time`](#smtp_sasl_auth_cache_time)
* [`smtp_sasl_auth_enable`](#smtp_sasl_auth_enable)
* [`smtp_sasl_auth_soft_bounce`](#smtp_sasl_auth_soft_bounce)
* [`smtp_sasl_mechanism_filter`](#smtp_sasl_mechanism_filter)
* [`smtp_sasl_password_maps`](#smtp_sasl_password_maps)
* [`smtp_sasl_path`](#smtp_sasl_path)
* [`smtp_sasl_security_options`](#smtp_sasl_security_options)
* [`smtp_sasl_tls_security_options`](#smtp_sasl_tls_security_options)
* [`smtp_sasl_tls_verified_security_options`](#smtp_sasl_tls_verified_security_options)
* [`smtp_sasl_type`](#smtp_sasl_type)
* [`smtp_send_dummy_mail_auth`](#smtp_send_dummy_mail_auth)
* [`smtp_send_xforward_command`](#smtp_send_xforward_command)
* [`smtp_sender_dependent_authentication`](#smtp_sender_dependent_authentication)
* [`smtp_skip_5xx_greeting`](#smtp_skip_5xx_greeting)
* [`smtp_skip_quit_response`](#smtp_skip_quit_response)
* [`smtp_starttls_timeout`](#smtp_starttls_timeout)
* [`smtp_tls_cafile`](#smtp_tls_cafile)
* [`smtp_tls_capath`](#smtp_tls_capath)
* [`smtp_tls_block_early_mail_reply`](#smtp_tls_block_early_mail_reply)
* [`smtp_tls_cert_file`](#smtp_tls_cert_file)
* [`smtp_tls_ciphers`](#smtp_tls_ciphers)
* [`smtp_tls_dcert_file`](#smtp_tls_dcert_file)
* [`smtp_tls_dkey_file`](#smtp_tls_dkey_file)
* [`smtp_tls_eccert_file`](#smtp_tls_eccert_file)
* [`smtp_tls_eckey_file`](#smtp_tls_eckey_file)
* [`smtp_tls_enforce_peername`](#smtp_tls_enforce_peername)
* [`smtp_tls_exclude_ciphers`](#smtp_tls_exclude_ciphers)
* [`smtp_tls_fingerprint_cert_match`](#smtp_tls_fingerprint_cert_match)
* [`smtp_tls_fingerprint_digest`](#smtp_tls_fingerprint_digest)
* [`smtp_tls_key_file`](#smtp_tls_key_file)
* [`smtp_tls_loglevel`](#smtp_tls_loglevel)
* [`smtp_tls_mandatory_ciphers`](#smtp_tls_mandatory_ciphers)
* [`smtp_tls_mandatory_exclude_ciphers`](#smtp_tls_mandatory_exclude_ciphers)
* [`smtp_tls_mandatory_protocols`](#smtp_tls_mandatory_protocols)
* [`smtp_tls_note_starttls_offer`](#smtp_tls_note_starttls_offer)
* [`smtp_tls_per_site`](#smtp_tls_per_site)
* [`smtp_tls_policy_maps`](#smtp_tls_policy_maps)
* [`smtp_tls_protocols`](#smtp_tls_protocols)
* [`smtp_tls_scert_verifydepth`](#smtp_tls_scert_verifydepth)
* [`smtp_tls_secure_cert_match`](#smtp_tls_secure_cert_match)
* [`smtp_tls_security_level`](#smtp_tls_security_level)
* [`smtp_tls_session_cache_database`](#smtp_tls_session_cache_database)
* [`smtp_tls_session_cache_timeout`](#smtp_tls_session_cache_timeout)
* [`smtp_tls_verify_cert_match`](#smtp_tls_verify_cert_match)
* [`smtp_use_tls`](#smtp_use_tls)
* [`smtp_xforward_timeout`](#smtp_xforward_timeout)
* [`smtpd_authorized_verp_clients`](#smtpd_authorized_verp_clients)
* [`smtpd_authorized_xclient_hosts`](#smtpd_authorized_xclient_hosts)
* [`smtpd_authorized_xforward_hosts`](#smtpd_authorized_xforward_hosts)
* [`smtpd_banner`](#smtpd_banner)
* [`smtpd_client_connection_count_limit`](#smtpd_client_connection_count_limit)
* [`smtpd_client_connection_rate_limit`](#smtpd_client_connection_rate_limit)
* [`smtpd_client_event_limit_exceptions`](#smtpd_client_event_limit_exceptions)
* [`smtpd_client_message_rate_limit`](#smtpd_client_message_rate_limit)
* [`smtpd_client_new_tls_session_rate_limit`](#smtpd_client_new_tls_session_rate_limit)
* [`smtpd_client_port_logging`](#smtpd_client_port_logging)
* [`smtpd_client_recipient_rate_limit`](#smtpd_client_recipient_rate_limit)
* [`smtpd_client_restrictions`](#smtpd_client_restrictions)
* [`smtpd_command_filter`](#smtpd_command_filter)
* [`smtpd_data_restrictions`](#smtpd_data_restrictions)
* [`smtpd_delay_open_until_valid_rcpt`](#smtpd_delay_open_until_valid_rcpt)
* [`smtpd_delay_reject`](#smtpd_delay_reject)
* [`smtpd_discard_ehlo_keyword_address_maps`](#smtpd_discard_ehlo_keyword_address_maps)
* [`smtpd_discard_ehlo_keywords`](#smtpd_discard_ehlo_keywords)
* [`smtpd_end_of_data_restrictions`](#smtpd_end_of_data_restrictions)
* [`smtpd_enforce_tls`](#smtpd_enforce_tls)
* [`smtpd_error_sleep_time`](#smtpd_error_sleep_time)
* [`smtpd_etrn_restrictions`](#smtpd_etrn_restrictions)
* [`smtpd_expansion_filter`](#smtpd_expansion_filter)
* [`smtpd_forbidden_commands`](#smtpd_forbidden_commands)
* [`smtpd_hard_error_limit`](#smtpd_hard_error_limit)
* [`smtpd_helo_required`](#smtpd_helo_required)
* [`smtpd_helo_restrictions`](#smtpd_helo_restrictions)
* [`smtpd_history_flush_threshold`](#smtpd_history_flush_threshold)
* [`smtpd_junk_command_limit`](#smtpd_junk_command_limit)
* [`smtpd_log_access_permit_actions`](#smtpd_log_access_permit_actions)
* [`smtpd_milters`](#smtpd_milters)
* [`smtpd_noop_commands`](#smtpd_noop_commands)
* [`smtpd_null_access_lookup_key`](#smtpd_null_access_lookup_key)
* [`smtpd_peername_lookup`](#smtpd_peername_lookup)
* [`smtpd_per_record_deadline`](#smtpd_per_record_deadline)
* [`smtpd_policy_service_max_idle`](#smtpd_policy_service_max_idle)
* [`smtpd_policy_service_max_ttl`](#smtpd_policy_service_max_ttl)
* [`smtpd_policy_service_timeout`](#smtpd_policy_service_timeout)
* [`smtpd_proxy_ehlo`](#smtpd_proxy_ehlo)
* [`smtpd_proxy_filter`](#smtpd_proxy_filter)
* [`smtpd_proxy_options`](#smtpd_proxy_options)
* [`smtpd_proxy_timeout`](#smtpd_proxy_timeout)
* [`smtpd_recipient_limit`](#smtpd_recipient_limit)
* [`smtpd_recipient_overshoot_limit`](#smtpd_recipient_overshoot_limit)
* [`smtpd_recipient_restrictions`](#smtpd_recipient_restrictions)
* [`smtpd_reject_footer`](#smtpd_reject_footer)
* [`smtpd_reject_unlisted_recipient`](#smtpd_reject_unlisted_recipient)
* [`smtpd_reject_unlisted_sender`](#smtpd_reject_unlisted_sender)
* [`smtpd_relay_restrictions`](#smtpd_relay_restrictions)
* [`smtpd_restriction_classes`](#smtpd_restriction_classes)
* [`smtpd_sasl_auth_enable`](#smtpd_sasl_auth_enable)
* [`smtpd_sasl_authenticated_header`](#smtpd_sasl_authenticated_header)
* [`smtpd_sasl_exceptions_networks`](#smtpd_sasl_exceptions_networks)
* [`smtpd_sasl_local_domain`](#smtpd_sasl_local_domain)
* [`smtpd_sasl_path`](#smtpd_sasl_path)
* [`smtpd_sasl_security_options`](#smtpd_sasl_security_options)
* [`smtpd_sasl_tls_security_options`](#smtpd_sasl_tls_security_options)
* [`smtpd_sasl_type`](#smtpd_sasl_type)
* [`smtpd_sender_login_maps`](#smtpd_sender_login_maps)
* [`smtpd_sender_restrictions`](#smtpd_sender_restrictions)
* [`smtpd_service_name`](#smtpd_service_name)
* [`smtpd_soft_error_limit`](#smtpd_soft_error_limit)
* [`smtpd_starttls_timeout`](#smtpd_starttls_timeout)
* [`smtpd_timeout`](#smtpd_timeout)
* [`smtpd_tls_cafile`](#smtpd_tls_cafile)
* [`smtpd_tls_capath`](#smtpd_tls_capath)
* [`smtpd_tls_always_issue_session_ids`](#smtpd_tls_always_issue_session_ids)
* [`smtpd_tls_ask_ccert`](#smtpd_tls_ask_ccert)
* [`smtpd_tls_auth_only`](#smtpd_tls_auth_only)
* [`smtpd_tls_ccert_verifydepth`](#smtpd_tls_ccert_verifydepth)
* [`smtpd_tls_cert_file`](#smtpd_tls_cert_file)
* [`smtpd_tls_ciphers`](#smtpd_tls_ciphers)
* [`smtpd_tls_dcert_file`](#smtpd_tls_dcert_file)
* [`smtpd_tls_dh1024_param_file`](#smtpd_tls_dh1024_param_file)
* [`smtpd_tls_dh512_param_file`](#smtpd_tls_dh512_param_file)
* [`smtpd_tls_dkey_file`](#smtpd_tls_dkey_file)
* [`smtpd_tls_eccert_file`](#smtpd_tls_eccert_file)
* [`smtpd_tls_eckey_file`](#smtpd_tls_eckey_file)
* [`smtpd_tls_eecdh_grade`](#smtpd_tls_eecdh_grade)
* [`smtpd_tls_exclude_ciphers`](#smtpd_tls_exclude_ciphers)
* [`smtpd_tls_fingerprint_digest`](#smtpd_tls_fingerprint_digest)
* [`smtpd_tls_key_file`](#smtpd_tls_key_file)
* [`smtpd_tls_loglevel`](#smtpd_tls_loglevel)
* [`smtpd_tls_mandatory_ciphers`](#smtpd_tls_mandatory_ciphers)
* [`smtpd_tls_mandatory_exclude_ciphers`](#smtpd_tls_mandatory_exclude_ciphers)
* [`smtpd_tls_mandatory_protocols`](#smtpd_tls_mandatory_protocols)
* [`smtpd_tls_protocols`](#smtpd_tls_protocols)
* [`smtpd_tls_received_header`](#smtpd_tls_received_header)
* [`smtpd_tls_req_ccert`](#smtpd_tls_req_ccert)
* [`smtpd_tls_security_level`](#smtpd_tls_security_level)
* [`smtpd_tls_session_cache_database`](#smtpd_tls_session_cache_database)
* [`smtpd_tls_session_cache_timeout`](#smtpd_tls_session_cache_timeout)
* [`smtpd_tls_wrappermode`](#smtpd_tls_wrappermode)
* [`smtpd_upstream_proxy_protocol`](#smtpd_upstream_proxy_protocol)
* [`smtpd_upstream_proxy_timeout`](#smtpd_upstream_proxy_timeout)
* [`smtpd_use_tls`](#smtpd_use_tls)
* [`soft_bounce`](#soft_bounce)
* [`stale_lock_time`](#stale_lock_time)
* [`strict_7bit_headers`](#strict_7bit_headers)
* [`strict_8bitmime`](#strict_8bitmime)
* [`strict_8bitmime_body`](#strict_8bitmime_body)
* [`strict_mailbox_ownership`](#strict_mailbox_ownership)
* [`strict_mime_encoding_domain`](#strict_mime_encoding_domain)
* [`strict_rfc821_envelopes`](#strict_rfc821_envelopes)
* [`sun_mailtool_compatibility`](#sun_mailtool_compatibility)
* [`swap_bangpath`](#swap_bangpath)
* [`syslog_facility`](#syslog_facility)
* [`syslog_name`](#syslog_name)
* [`tcp_windowsize`](#tcp_windowsize)
* [`tls_append_default_ca`](#tls_append_default_ca)
* [`tls_daemon_random_bytes`](#tls_daemon_random_bytes)
* [`tls_disable_workarounds`](#tls_disable_workarounds)
* [`tls_eecdh_strong_curve`](#tls_eecdh_strong_curve)
* [`tls_eecdh_ultra_curve`](#tls_eecdh_ultra_curve)
* [`tls_export_cipherlist`](#tls_export_cipherlist)
* [`tls_high_cipherlist`](#tls_high_cipherlist)
* [`tls_legacy_public_key_fingerprints`](#tls_legacy_public_key_fingerprints)
* [`tls_low_cipherlist`](#tls_low_cipherlist)
* [`tls_medium_cipherlist`](#tls_medium_cipherlist)
* [`tls_null_cipherlist`](#tls_null_cipherlist)
* [`tls_preempt_cipherlist`](#tls_preempt_cipherlist)
* [`tls_random_bytes`](#tls_random_bytes)
* [`tls_random_exchange_name`](#tls_random_exchange_name)
* [`tls_random_prng_update_period`](#tls_random_prng_update_period)
* [`tls_random_reseed_period`](#tls_random_reseed_period)
* [`tls_random_source`](#tls_random_source)
* [`tlsproxy_enforce_tls`](#tlsproxy_enforce_tls)
* [`tlsproxy_service_name`](#tlsproxy_service_name)
* [`tlsproxy_tls_cafile`](#tlsproxy_tls_cafile)
* [`tlsproxy_tls_capath`](#tlsproxy_tls_capath)
* [`tlsproxy_tls_always_issue_session_ids`](#tlsproxy_tls_always_issue_session_ids)
* [`tlsproxy_tls_ask_ccert`](#tlsproxy_tls_ask_ccert)
* [`tlsproxy_tls_ccert_verifydepth`](#tlsproxy_tls_ccert_verifydepth)
* [`tlsproxy_tls_cert_file`](#tlsproxy_tls_cert_file)
* [`tlsproxy_tls_ciphers`](#tlsproxy_tls_ciphers)
* [`tlsproxy_tls_dcert_file`](#tlsproxy_tls_dcert_file)
* [`tlsproxy_tls_dh1024_param_file`](#tlsproxy_tls_dh1024_param_file)
* [`tlsproxy_tls_dh512_param_file`](#tlsproxy_tls_dh512_param_file)
* [`tlsproxy_tls_dkey_file`](#tlsproxy_tls_dkey_file)
* [`tlsproxy_tls_eccert_file`](#tlsproxy_tls_eccert_file)
* [`tlsproxy_tls_eckey_file`](#tlsproxy_tls_eckey_file)
* [`tlsproxy_tls_eecdh_grade`](#tlsproxy_tls_eecdh_grade)
* [`tlsproxy_tls_exclude_ciphers`](#tlsproxy_tls_exclude_ciphers)
* [`tlsproxy_tls_fingerprint_digest`](#tlsproxy_tls_fingerprint_digest)
* [`tlsproxy_tls_key_file`](#tlsproxy_tls_key_file)
* [`tlsproxy_tls_loglevel`](#tlsproxy_tls_loglevel)
* [`tlsproxy_tls_mandatory_ciphers`](#tlsproxy_tls_mandatory_ciphers)
* [`tlsproxy_tls_mandatory_exclude_ciphers`](#tlsproxy_tls_mandatory_exclude_ciphers)
* [`tlsproxy_tls_mandatory_protocols`](#tlsproxy_tls_mandatory_protocols)
* [`tlsproxy_tls_protocols`](#tlsproxy_tls_protocols)
* [`tlsproxy_tls_req_ccert`](#tlsproxy_tls_req_ccert)
* [`tlsproxy_tls_security_level`](#tlsproxy_tls_security_level)
* [`tlsproxy_tls_session_cache_timeout`](#tlsproxy_tls_session_cache_timeout)
* [`tlsproxy_use_tls`](#tlsproxy_use_tls)
* [`tlsproxy_watchdog_timeout`](#tlsproxy_watchdog_timeout)
* [`trace_service_name`](#trace_service_name)
* [`transport_maps`](#transport_maps)
* [`transport_retry_time`](#transport_retry_time)
* [`trigger_timeout`](#trigger_timeout)
* [`undisclosed_recipients_header`](#undisclosed_recipients_header)
* [`unknown_address_reject_code`](#unknown_address_reject_code)
* [`unknown_address_tempfail_action`](#unknown_address_tempfail_action)
* [`unknown_client_reject_code`](#unknown_client_reject_code)
* [`unknown_helo_hostname_tempfail_action`](#unknown_helo_hostname_tempfail_action)
* [`unknown_hostname_reject_code`](#unknown_hostname_reject_code)
* [`unknown_local_recipient_reject_code`](#unknown_local_recipient_reject_code)
* [`unknown_relay_recipient_reject_code`](#unknown_relay_recipient_reject_code)
* [`unknown_virtual_alias_reject_code`](#unknown_virtual_alias_reject_code)
* [`unknown_virtual_mailbox_reject_code`](#unknown_virtual_mailbox_reject_code)
* [`unverified_recipient_defer_code`](#unverified_recipient_defer_code)
* [`unverified_recipient_reject_code`](#unverified_recipient_reject_code)
* [`unverified_recipient_reject_reason`](#unverified_recipient_reject_reason)
* [`unverified_recipient_tempfail_action`](#unverified_recipient_tempfail_action)
* [`unverified_sender_defer_code`](#unverified_sender_defer_code)
* [`unverified_sender_reject_code`](#unverified_sender_reject_code)
* [`unverified_sender_reject_reason`](#unverified_sender_reject_reason)
* [`unverified_sender_tempfail_action`](#unverified_sender_tempfail_action)
* [`verp_delimiter_filter`](#verp_delimiter_filter)
* [`virtual_alias_domains`](#virtual_alias_domains)
* [`virtual_alias_expansion_limit`](#virtual_alias_expansion_limit)
* [`virtual_alias_maps`](#virtual_alias_maps)
* [`virtual_alias_recursion_limit`](#virtual_alias_recursion_limit)
* [`virtual_gid_maps`](#virtual_gid_maps)
* [`virtual_mailbox_base`](#virtual_mailbox_base)
* [`virtual_mailbox_domains`](#virtual_mailbox_domains)
* [`virtual_mailbox_limit`](#virtual_mailbox_limit)
* [`virtual_mailbox_lock`](#virtual_mailbox_lock)
* [`virtual_mailbox_maps`](#virtual_mailbox_maps)
* [`virtual_minimum_uid`](#virtual_minimum_uid)
* [`virtual_transport`](#virtual_transport)
* [`virtual_uid_maps`](#virtual_uid_maps)

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`



##### <a name="services"></a>`services`

Data type: `Hash[String, Hash[String, Any]]`



##### <a name="lookup_packages"></a>`lookup_packages`

Data type: `Hash[Postfix::Type::Lookup, String]`



##### <a name="package_name"></a>`package_name`

Data type: `String`



##### <a name="service_name"></a>`service_name`

Data type: `String`



##### <a name="twobounce_notice_recipient"></a>`twobounce_notice_recipient`

Data type: `Optional[String]`

`2bounce_notice_recipient` is a violation
of Puppet variable naming conventions.

##### <a name="access_map_defer_code"></a>`access_map_defer_code`

Data type: `Optional[String]`



##### <a name="access_map_reject_code"></a>`access_map_reject_code`

Data type: `Optional[String]`



##### <a name="address_verify_cache_cleanup_interval"></a>`address_verify_cache_cleanup_interval`

Data type: `Optional[String]`



##### <a name="address_verify_default_transport"></a>`address_verify_default_transport`

Data type: `Optional[String]`



##### <a name="address_verify_local_transport"></a>`address_verify_local_transport`

Data type: `Optional[String]`



##### <a name="address_verify_map"></a>`address_verify_map`

Data type: `Optional[String]`



##### <a name="address_verify_negative_cache"></a>`address_verify_negative_cache`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="address_verify_negative_expire_time"></a>`address_verify_negative_expire_time`

Data type: `Optional[String]`



##### <a name="address_verify_negative_refresh_time"></a>`address_verify_negative_refresh_time`

Data type: `Optional[String]`



##### <a name="address_verify_poll_count"></a>`address_verify_poll_count`

Data type: `Optional[String]`



##### <a name="address_verify_poll_delay"></a>`address_verify_poll_delay`

Data type: `Optional[String]`



##### <a name="address_verify_positive_expire_time"></a>`address_verify_positive_expire_time`

Data type: `Optional[String]`



##### <a name="address_verify_positive_refresh_time"></a>`address_verify_positive_refresh_time`

Data type: `Optional[String]`



##### <a name="address_verify_relay_transport"></a>`address_verify_relay_transport`

Data type: `Optional[String]`



##### <a name="address_verify_relayhost"></a>`address_verify_relayhost`

Data type: `Optional[String]`



##### <a name="address_verify_sender"></a>`address_verify_sender`

Data type: `Optional[String]`



##### <a name="address_verify_sender_dependent_default_transport_maps"></a>`address_verify_sender_dependent_default_transport_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="address_verify_sender_dependent_relayhost_maps"></a>`address_verify_sender_dependent_relayhost_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="address_verify_sender_ttl"></a>`address_verify_sender_ttl`

Data type: `Optional[String]`



##### <a name="address_verify_service_name"></a>`address_verify_service_name`

Data type: `Optional[String]`



##### <a name="address_verify_transport_maps"></a>`address_verify_transport_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="address_verify_virtual_transport"></a>`address_verify_virtual_transport`

Data type: `Optional[String]`



##### <a name="alias_database"></a>`alias_database`

Data type: `Optional[Array[String, 1]]`



##### <a name="alias_maps"></a>`alias_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="allow_mail_to_commands"></a>`allow_mail_to_commands`

Data type: `Optional[Array[String, 1]]`



##### <a name="allow_mail_to_files"></a>`allow_mail_to_files`

Data type: `Optional[Array[String, 1]]`



##### <a name="allow_min_user"></a>`allow_min_user`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="allow_percent_hack"></a>`allow_percent_hack`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="allow_untrusted_routing"></a>`allow_untrusted_routing`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="alternate_config_directories"></a>`alternate_config_directories`

Data type: `Optional[Array[String, 1]]`



##### <a name="always_add_missing_headers"></a>`always_add_missing_headers`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="always_bcc"></a>`always_bcc`

Data type: `Optional[String]`



##### <a name="anvil_rate_time_unit"></a>`anvil_rate_time_unit`

Data type: `Optional[String]`



##### <a name="anvil_status_update_time"></a>`anvil_status_update_time`

Data type: `Optional[String]`



##### <a name="append_at_myorigin"></a>`append_at_myorigin`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="append_dot_mydomain"></a>`append_dot_mydomain`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="application_event_drain_time"></a>`application_event_drain_time`

Data type: `Optional[String]`



##### <a name="authorized_flush_users"></a>`authorized_flush_users`

Data type: `Optional[Array[String, 1]]`



##### <a name="authorized_mailq_users"></a>`authorized_mailq_users`

Data type: `Optional[Array[String, 1]]`



##### <a name="authorized_submit_users"></a>`authorized_submit_users`

Data type: `Optional[Array[String, 1]]`



##### <a name="backwards_bounce_logfile_compatibility"></a>`backwards_bounce_logfile_compatibility`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="berkeley_db_create_buffer_size"></a>`berkeley_db_create_buffer_size`

Data type: `Optional[String]`



##### <a name="berkeley_db_read_buffer_size"></a>`berkeley_db_read_buffer_size`

Data type: `Optional[String]`



##### <a name="best_mx_transport"></a>`best_mx_transport`

Data type: `Optional[String]`



##### <a name="biff"></a>`biff`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="body_checks"></a>`body_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="body_checks_size_limit"></a>`body_checks_size_limit`

Data type: `Optional[String]`



##### <a name="bounce_notice_recipient"></a>`bounce_notice_recipient`

Data type: `Optional[String]`



##### <a name="bounce_queue_lifetime"></a>`bounce_queue_lifetime`

Data type: `Optional[String]`



##### <a name="bounce_service_name"></a>`bounce_service_name`

Data type: `Optional[String]`



##### <a name="bounce_size_limit"></a>`bounce_size_limit`

Data type: `Optional[String]`



##### <a name="bounce_template_file"></a>`bounce_template_file`

Data type: `Optional[String]`



##### <a name="broken_sasl_auth_clients"></a>`broken_sasl_auth_clients`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="canonical_classes"></a>`canonical_classes`

Data type: `Optional[Array[String, 1]]`



##### <a name="canonical_maps"></a>`canonical_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="cleanup_service_name"></a>`cleanup_service_name`

Data type: `Optional[String]`



##### <a name="command_directory"></a>`command_directory`

Data type: `Optional[String]`



##### <a name="command_execution_directory"></a>`command_execution_directory`

Data type: `Optional[String]`



##### <a name="command_expansion_filter"></a>`command_expansion_filter`

Data type: `Optional[String]`



##### <a name="command_time_limit"></a>`command_time_limit`

Data type: `Optional[String]`



##### <a name="compatibility_level"></a>`compatibility_level`

Data type: `Optional[String]`



##### <a name="config_directory"></a>`config_directory`

Data type: `Optional[String]`



##### <a name="connection_cache_protocol_timeout"></a>`connection_cache_protocol_timeout`

Data type: `Optional[String]`



##### <a name="connection_cache_service_name"></a>`connection_cache_service_name`

Data type: `Optional[String]`



##### <a name="connection_cache_status_update_time"></a>`connection_cache_status_update_time`

Data type: `Optional[String]`



##### <a name="connection_cache_ttl_limit"></a>`connection_cache_ttl_limit`

Data type: `Optional[String]`



##### <a name="content_filter"></a>`content_filter`

Data type: `Optional[String]`



##### <a name="cyrus_sasl_config_path"></a>`cyrus_sasl_config_path`

Data type: `Optional[Array[String, 1]]`



##### <a name="daemon_directory"></a>`daemon_directory`

Data type: `Optional[String]`



##### <a name="daemon_table_open_error_is_fatal"></a>`daemon_table_open_error_is_fatal`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="daemon_timeout"></a>`daemon_timeout`

Data type: `Optional[String]`



##### <a name="data_directory"></a>`data_directory`

Data type: `Optional[String]`



##### <a name="debug_peer_level"></a>`debug_peer_level`

Data type: `Optional[String]`



##### <a name="debug_peer_list"></a>`debug_peer_list`

Data type: `Optional[Array[String, 1]]`



##### <a name="debugger_command"></a>`debugger_command`

Data type: `Optional[String]`



##### <a name="default_database_type"></a>`default_database_type`

Data type: `Postfix::Type::Lookup::Database`



##### <a name="default_delivery_slot_cost"></a>`default_delivery_slot_cost`

Data type: `Optional[String]`



##### <a name="default_delivery_slot_discount"></a>`default_delivery_slot_discount`

Data type: `Optional[String]`



##### <a name="default_delivery_slot_loan"></a>`default_delivery_slot_loan`

Data type: `Optional[String]`



##### <a name="default_destination_concurrency_failed_cohort_limit"></a>`default_destination_concurrency_failed_cohort_limit`

Data type: `Optional[String]`



##### <a name="default_destination_concurrency_limit"></a>`default_destination_concurrency_limit`

Data type: `Optional[String]`



##### <a name="default_destination_concurrency_negative_feedback"></a>`default_destination_concurrency_negative_feedback`

Data type: `Optional[String]`



##### <a name="default_destination_concurrency_positive_feedback"></a>`default_destination_concurrency_positive_feedback`

Data type: `Optional[String]`



##### <a name="default_destination_rate_delay"></a>`default_destination_rate_delay`

Data type: `Optional[String]`



##### <a name="default_destination_recipient_limit"></a>`default_destination_recipient_limit`

Data type: `Optional[String]`



##### <a name="default_extra_recipient_limit"></a>`default_extra_recipient_limit`

Data type: `Optional[String]`



##### <a name="default_filter_nexthop"></a>`default_filter_nexthop`

Data type: `Optional[String]`



##### <a name="default_minimum_delivery_slots"></a>`default_minimum_delivery_slots`

Data type: `Optional[String]`



##### <a name="default_privs"></a>`default_privs`

Data type: `Optional[String]`



##### <a name="default_process_limit"></a>`default_process_limit`

Data type: `Optional[String]`



##### <a name="default_rbl_reply"></a>`default_rbl_reply`

Data type: `Optional[String]`



##### <a name="default_recipient_limit"></a>`default_recipient_limit`

Data type: `Optional[String]`



##### <a name="default_recipient_refill_delay"></a>`default_recipient_refill_delay`

Data type: `Optional[String]`



##### <a name="default_recipient_refill_limit"></a>`default_recipient_refill_limit`

Data type: `Optional[String]`



##### <a name="default_transport"></a>`default_transport`

Data type: `Optional[String]`



##### <a name="default_verp_delimiters"></a>`default_verp_delimiters`

Data type: `Optional[String]`



##### <a name="defer_code"></a>`defer_code`

Data type: `Optional[String]`



##### <a name="defer_service_name"></a>`defer_service_name`

Data type: `Optional[String]`



##### <a name="defer_transports"></a>`defer_transports`

Data type: `Optional[Array[String, 1]]`



##### <a name="delay_logging_resolution_limit"></a>`delay_logging_resolution_limit`

Data type: `Optional[String]`



##### <a name="delay_notice_recipient"></a>`delay_notice_recipient`

Data type: `Optional[String]`



##### <a name="delay_warning_time"></a>`delay_warning_time`

Data type: `Optional[String]`



##### <a name="deliver_lock_attempts"></a>`deliver_lock_attempts`

Data type: `Optional[String]`



##### <a name="deliver_lock_delay"></a>`deliver_lock_delay`

Data type: `Optional[String]`



##### <a name="destination_concurrency_feedback_debug"></a>`destination_concurrency_feedback_debug`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="detect_8bit_encoding_header"></a>`detect_8bit_encoding_header`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="disable_dns_lookups"></a>`disable_dns_lookups`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="disable_mime_input_processing"></a>`disable_mime_input_processing`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="disable_mime_output_conversion"></a>`disable_mime_output_conversion`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="disable_verp_bounces"></a>`disable_verp_bounces`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="disable_vrfy_command"></a>`disable_vrfy_command`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="dnsblog_reply_delay"></a>`dnsblog_reply_delay`

Data type: `Optional[String]`



##### <a name="dnsblog_service_name"></a>`dnsblog_service_name`

Data type: `Optional[String]`



##### <a name="dont_remove"></a>`dont_remove`

Data type: `Optional[String]`



##### <a name="double_bounce_sender"></a>`double_bounce_sender`

Data type: `Optional[String]`



##### <a name="duplicate_filter_limit"></a>`duplicate_filter_limit`

Data type: `Optional[String]`



##### <a name="empty_address_default_transport_maps_lookup_key"></a>`empty_address_default_transport_maps_lookup_key`

Data type: `Optional[String]`



##### <a name="empty_address_recipient"></a>`empty_address_recipient`

Data type: `Optional[String]`



##### <a name="empty_address_relayhost_maps_lookup_key"></a>`empty_address_relayhost_maps_lookup_key`

Data type: `Optional[String]`



##### <a name="enable_long_queue_ids"></a>`enable_long_queue_ids`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="enable_original_recipient"></a>`enable_original_recipient`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="error_notice_recipient"></a>`error_notice_recipient`

Data type: `Optional[String]`



##### <a name="error_service_name"></a>`error_service_name`

Data type: `Optional[String]`



##### <a name="execution_directory_expansion_filter"></a>`execution_directory_expansion_filter`

Data type: `Optional[String]`



##### <a name="expand_owner_alias"></a>`expand_owner_alias`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="export_environment"></a>`export_environment`

Data type: `Optional[Array[String, 1]]`



##### <a name="fallback_transport"></a>`fallback_transport`

Data type: `Optional[String]`



##### <a name="fallback_transport_maps"></a>`fallback_transport_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="fast_flush_domains"></a>`fast_flush_domains`

Data type: `Optional[Array[String, 1]]`



##### <a name="fast_flush_purge_time"></a>`fast_flush_purge_time`

Data type: `Optional[String]`



##### <a name="fast_flush_refresh_time"></a>`fast_flush_refresh_time`

Data type: `Optional[String]`



##### <a name="fault_injection_code"></a>`fault_injection_code`

Data type: `Optional[String]`



##### <a name="flush_service_name"></a>`flush_service_name`

Data type: `Optional[String]`



##### <a name="fork_attempts"></a>`fork_attempts`

Data type: `Optional[String]`



##### <a name="fork_delay"></a>`fork_delay`

Data type: `Optional[String]`



##### <a name="forward_expansion_filter"></a>`forward_expansion_filter`

Data type: `Optional[String]`



##### <a name="forward_path"></a>`forward_path`

Data type: `Optional[Array[String, 1]]`



##### <a name="frozen_delivered_to"></a>`frozen_delivered_to`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="hash_queue_depth"></a>`hash_queue_depth`

Data type: `Optional[String]`



##### <a name="hash_queue_names"></a>`hash_queue_names`

Data type: `Optional[Array[String, 1]]`



##### <a name="header_address_token_limit"></a>`header_address_token_limit`

Data type: `Optional[String]`



##### <a name="header_checks"></a>`header_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="header_size_limit"></a>`header_size_limit`

Data type: `Optional[String]`



##### <a name="helpful_warnings"></a>`helpful_warnings`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="home_mailbox"></a>`home_mailbox`

Data type: `Optional[String]`



##### <a name="hopcount_limit"></a>`hopcount_limit`

Data type: `Optional[String]`



##### <a name="html_directory"></a>`html_directory`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="ignore_mx_lookup_error"></a>`ignore_mx_lookup_error`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="import_environment"></a>`import_environment`

Data type: `Optional[Array[String, 1]]`



##### <a name="in_flow_delay"></a>`in_flow_delay`

Data type: `Optional[String]`



##### <a name="inet_interfaces"></a>`inet_interfaces`

Data type: `Optional[Array[String, 1]]`



##### <a name="inet_protocols"></a>`inet_protocols`

Data type: `Optional[Array[String, 1]]`



##### <a name="initial_destination_concurrency"></a>`initial_destination_concurrency`

Data type: `Optional[String]`



##### <a name="internal_mail_filter_classes"></a>`internal_mail_filter_classes`

Data type: `Optional[Array[String, 1]]`



##### <a name="invalid_hostname_reject_code"></a>`invalid_hostname_reject_code`

Data type: `Optional[String]`



##### <a name="ipc_idle"></a>`ipc_idle`

Data type: `Optional[String]`



##### <a name="ipc_timeout"></a>`ipc_timeout`

Data type: `Optional[String]`



##### <a name="ipc_ttl"></a>`ipc_ttl`

Data type: `Optional[String]`



##### <a name="line_length_limit"></a>`line_length_limit`

Data type: `Optional[String]`



##### <a name="lmtp_address_preference"></a>`lmtp_address_preference`

Data type: `Optional[String]`



##### <a name="lmtp_assume_final"></a>`lmtp_assume_final`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_bind_address"></a>`lmtp_bind_address`

Data type: `Optional[String]`



##### <a name="lmtp_bind_address6"></a>`lmtp_bind_address6`

Data type: `Optional[String]`



##### <a name="lmtp_body_checks"></a>`lmtp_body_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_cname_overrides_servername"></a>`lmtp_cname_overrides_servername`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_connect_timeout"></a>`lmtp_connect_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_connection_cache_destinations"></a>`lmtp_connection_cache_destinations`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_connection_cache_on_demand"></a>`lmtp_connection_cache_on_demand`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_connection_cache_time_limit"></a>`lmtp_connection_cache_time_limit`

Data type: `Optional[String]`



##### <a name="lmtp_connection_reuse_time_limit"></a>`lmtp_connection_reuse_time_limit`

Data type: `Optional[String]`



##### <a name="lmtp_data_done_timeout"></a>`lmtp_data_done_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_data_init_timeout"></a>`lmtp_data_init_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_data_xfer_timeout"></a>`lmtp_data_xfer_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_defer_if_no_mx_address_found"></a>`lmtp_defer_if_no_mx_address_found`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_discard_lhlo_keyword_address_maps"></a>`lmtp_discard_lhlo_keyword_address_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_discard_lhlo_keywords"></a>`lmtp_discard_lhlo_keywords`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_dns_resolver_options"></a>`lmtp_dns_resolver_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_enforce_tls"></a>`lmtp_enforce_tls`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_generic_maps"></a>`lmtp_generic_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_header_checks"></a>`lmtp_header_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_host_lookup"></a>`lmtp_host_lookup`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_lhlo_name"></a>`lmtp_lhlo_name`

Data type: `Optional[String]`



##### <a name="lmtp_lhlo_timeout"></a>`lmtp_lhlo_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_line_length_limit"></a>`lmtp_line_length_limit`

Data type: `Optional[String]`



##### <a name="lmtp_mail_timeout"></a>`lmtp_mail_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_mime_header_checks"></a>`lmtp_mime_header_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_mx_address_limit"></a>`lmtp_mx_address_limit`

Data type: `Optional[String]`



##### <a name="lmtp_mx_session_limit"></a>`lmtp_mx_session_limit`

Data type: `Optional[String]`



##### <a name="lmtp_nested_header_checks"></a>`lmtp_nested_header_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_per_record_deadline"></a>`lmtp_per_record_deadline`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_pix_workaround_delay_time"></a>`lmtp_pix_workaround_delay_time`

Data type: `Optional[String]`



##### <a name="lmtp_pix_workaround_maps"></a>`lmtp_pix_workaround_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_pix_workaround_threshold_time"></a>`lmtp_pix_workaround_threshold_time`

Data type: `Optional[String]`



##### <a name="lmtp_pix_workarounds"></a>`lmtp_pix_workarounds`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_quit_timeout"></a>`lmtp_quit_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_quote_rfc821_envelope"></a>`lmtp_quote_rfc821_envelope`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_randomize_addresses"></a>`lmtp_randomize_addresses`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_rcpt_timeout"></a>`lmtp_rcpt_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_reply_filter"></a>`lmtp_reply_filter`

Data type: `Optional[String]`



##### <a name="lmtp_rset_timeout"></a>`lmtp_rset_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_sasl_auth_cache_name"></a>`lmtp_sasl_auth_cache_name`

Data type: `Optional[String]`



##### <a name="lmtp_sasl_auth_cache_time"></a>`lmtp_sasl_auth_cache_time`

Data type: `Optional[String]`



##### <a name="lmtp_sasl_auth_enable"></a>`lmtp_sasl_auth_enable`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_sasl_auth_soft_bounce"></a>`lmtp_sasl_auth_soft_bounce`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_sasl_mechanism_filter"></a>`lmtp_sasl_mechanism_filter`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_sasl_password_maps"></a>`lmtp_sasl_password_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_sasl_path"></a>`lmtp_sasl_path`

Data type: `Optional[String]`



##### <a name="lmtp_sasl_security_options"></a>`lmtp_sasl_security_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_sasl_tls_security_options"></a>`lmtp_sasl_tls_security_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_sasl_tls_verified_security_options"></a>`lmtp_sasl_tls_verified_security_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_sasl_type"></a>`lmtp_sasl_type`

Data type: `Optional[String]`



##### <a name="lmtp_send_dummy_mail_auth"></a>`lmtp_send_dummy_mail_auth`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_send_xforward_command"></a>`lmtp_send_xforward_command`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_sender_dependent_authentication"></a>`lmtp_sender_dependent_authentication`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_skip_5xx_greeting"></a>`lmtp_skip_5xx_greeting`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_skip_quit_response"></a>`lmtp_skip_quit_response`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_starttls_timeout"></a>`lmtp_starttls_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_tcp_port"></a>`lmtp_tcp_port`

Data type: `Optional[String]`



##### <a name="lmtp_tls_cafile"></a>`lmtp_tls_cafile`

Data type: `Optional[String]`



##### <a name="lmtp_tls_capath"></a>`lmtp_tls_capath`

Data type: `Optional[String]`



##### <a name="lmtp_tls_block_early_mail_reply"></a>`lmtp_tls_block_early_mail_reply`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_tls_cert_file"></a>`lmtp_tls_cert_file`

Data type: `Optional[String]`



##### <a name="lmtp_tls_ciphers"></a>`lmtp_tls_ciphers`

Data type: `Optional[String]`



##### <a name="lmtp_tls_dcert_file"></a>`lmtp_tls_dcert_file`

Data type: `Optional[String]`



##### <a name="lmtp_tls_dkey_file"></a>`lmtp_tls_dkey_file`

Data type: `Optional[String]`



##### <a name="lmtp_tls_eccert_file"></a>`lmtp_tls_eccert_file`

Data type: `Optional[String]`



##### <a name="lmtp_tls_eckey_file"></a>`lmtp_tls_eckey_file`

Data type: `Optional[String]`



##### <a name="lmtp_tls_enforce_peername"></a>`lmtp_tls_enforce_peername`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_tls_exclude_ciphers"></a>`lmtp_tls_exclude_ciphers`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_tls_fingerprint_cert_match"></a>`lmtp_tls_fingerprint_cert_match`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_tls_fingerprint_digest"></a>`lmtp_tls_fingerprint_digest`

Data type: `Optional[String]`



##### <a name="lmtp_tls_key_file"></a>`lmtp_tls_key_file`

Data type: `Optional[String]`



##### <a name="lmtp_tls_loglevel"></a>`lmtp_tls_loglevel`

Data type: `Optional[String]`



##### <a name="lmtp_tls_mandatory_ciphers"></a>`lmtp_tls_mandatory_ciphers`

Data type: `Optional[String]`



##### <a name="lmtp_tls_mandatory_exclude_ciphers"></a>`lmtp_tls_mandatory_exclude_ciphers`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_tls_mandatory_protocols"></a>`lmtp_tls_mandatory_protocols`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_tls_note_starttls_offer"></a>`lmtp_tls_note_starttls_offer`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_tls_per_site"></a>`lmtp_tls_per_site`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_tls_policy_maps"></a>`lmtp_tls_policy_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_tls_protocols"></a>`lmtp_tls_protocols`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_tls_scert_verifydepth"></a>`lmtp_tls_scert_verifydepth`

Data type: `Optional[String]`



##### <a name="lmtp_tls_secure_cert_match"></a>`lmtp_tls_secure_cert_match`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_tls_security_level"></a>`lmtp_tls_security_level`

Data type: `Optional[String]`



##### <a name="lmtp_tls_session_cache_database"></a>`lmtp_tls_session_cache_database`

Data type: `Optional[String]`



##### <a name="lmtp_tls_session_cache_timeout"></a>`lmtp_tls_session_cache_timeout`

Data type: `Optional[String]`



##### <a name="lmtp_tls_verify_cert_match"></a>`lmtp_tls_verify_cert_match`

Data type: `Optional[Array[String, 1]]`



##### <a name="lmtp_use_tls"></a>`lmtp_use_tls`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="lmtp_xforward_timeout"></a>`lmtp_xforward_timeout`

Data type: `Optional[String]`



##### <a name="local_command_shell"></a>`local_command_shell`

Data type: `Optional[String]`



##### <a name="local_header_rewrite_clients"></a>`local_header_rewrite_clients`

Data type: `Optional[Array[String, 1]]`



##### <a name="local_recipient_maps"></a>`local_recipient_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="local_transport"></a>`local_transport`

Data type: `Optional[String]`



##### <a name="luser_relay"></a>`luser_relay`

Data type: `Optional[String]`



##### <a name="mail_name"></a>`mail_name`

Data type: `Optional[String]`



##### <a name="mail_owner"></a>`mail_owner`

Data type: `Optional[String]`



##### <a name="mail_release_date"></a>`mail_release_date`

Data type: `Optional[String]`



##### <a name="mail_spool_directory"></a>`mail_spool_directory`

Data type: `Optional[String]`



##### <a name="mail_version"></a>`mail_version`

Data type: `Optional[String]`



##### <a name="mailbox_command"></a>`mailbox_command`

Data type: `Optional[String]`



##### <a name="mailbox_command_maps"></a>`mailbox_command_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="mailbox_delivery_lock"></a>`mailbox_delivery_lock`

Data type: `Optional[Array[String, 1]]`



##### <a name="mailbox_size_limit"></a>`mailbox_size_limit`

Data type: `Optional[String]`



##### <a name="mailbox_transport"></a>`mailbox_transport`

Data type: `Optional[String]`



##### <a name="mailbox_transport_maps"></a>`mailbox_transport_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="mailq_path"></a>`mailq_path`

Data type: `Optional[String]`



##### <a name="manpage_directory"></a>`manpage_directory`

Data type: `Optional[String]`



##### <a name="maps_rbl_domains"></a>`maps_rbl_domains`

Data type: `Optional[Array[String, 1]]`



##### <a name="maps_rbl_reject_code"></a>`maps_rbl_reject_code`

Data type: `Optional[String]`



##### <a name="masquerade_classes"></a>`masquerade_classes`

Data type: `Optional[Array[String, 1]]`



##### <a name="masquerade_domains"></a>`masquerade_domains`

Data type: `Optional[Array[String, 1]]`



##### <a name="masquerade_exceptions"></a>`masquerade_exceptions`

Data type: `Optional[Array[String, 1]]`



##### <a name="master_service_disable"></a>`master_service_disable`

Data type: `Optional[Array[String, 1]]`



##### <a name="max_idle"></a>`max_idle`

Data type: `Optional[String]`



##### <a name="max_use"></a>`max_use`

Data type: `Optional[String]`



##### <a name="maximal_backoff_time"></a>`maximal_backoff_time`

Data type: `Optional[String]`



##### <a name="maximal_queue_lifetime"></a>`maximal_queue_lifetime`

Data type: `Optional[String]`



##### <a name="message_reject_characters"></a>`message_reject_characters`

Data type: `Optional[String]`



##### <a name="message_size_limit"></a>`message_size_limit`

Data type: `Optional[String]`



##### <a name="message_strip_characters"></a>`message_strip_characters`

Data type: `Optional[String]`



##### <a name="meta_directory"></a>`meta_directory`

Data type: `Optional[String]`



##### <a name="milter_command_timeout"></a>`milter_command_timeout`

Data type: `Optional[String]`



##### <a name="milter_connect_macros"></a>`milter_connect_macros`

Data type: `Optional[String]`



##### <a name="milter_connect_timeout"></a>`milter_connect_timeout`

Data type: `Optional[String]`



##### <a name="milter_content_timeout"></a>`milter_content_timeout`

Data type: `Optional[String]`



##### <a name="milter_data_macros"></a>`milter_data_macros`

Data type: `Optional[String]`



##### <a name="milter_default_action"></a>`milter_default_action`

Data type: `Optional[String]`



##### <a name="milter_end_of_data_macros"></a>`milter_end_of_data_macros`

Data type: `Optional[String]`



##### <a name="milter_end_of_header_macros"></a>`milter_end_of_header_macros`

Data type: `Optional[String]`



##### <a name="milter_header_checks"></a>`milter_header_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="milter_helo_macros"></a>`milter_helo_macros`

Data type: `Optional[String]`



##### <a name="milter_macro_daemon_name"></a>`milter_macro_daemon_name`

Data type: `Optional[String]`



##### <a name="milter_macro_v"></a>`milter_macro_v`

Data type: `Optional[String]`



##### <a name="milter_mail_macros"></a>`milter_mail_macros`

Data type: `Optional[String]`



##### <a name="milter_protocol"></a>`milter_protocol`

Data type: `Optional[String]`



##### <a name="milter_rcpt_macros"></a>`milter_rcpt_macros`

Data type: `Optional[String]`



##### <a name="milter_unknown_command_macros"></a>`milter_unknown_command_macros`

Data type: `Optional[String]`



##### <a name="mime_boundary_length_limit"></a>`mime_boundary_length_limit`

Data type: `Optional[String]`



##### <a name="mime_header_checks"></a>`mime_header_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="mime_nesting_limit"></a>`mime_nesting_limit`

Data type: `Optional[String]`



##### <a name="minimal_backoff_time"></a>`minimal_backoff_time`

Data type: `Optional[String]`



##### <a name="multi_instance_directories"></a>`multi_instance_directories`

Data type: `Optional[Array[String, 1]]`



##### <a name="multi_instance_enable"></a>`multi_instance_enable`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="multi_instance_group"></a>`multi_instance_group`

Data type: `Optional[String]`



##### <a name="multi_instance_name"></a>`multi_instance_name`

Data type: `Optional[String]`



##### <a name="multi_instance_wrapper"></a>`multi_instance_wrapper`

Data type: `Optional[String]`



##### <a name="multi_recipient_bounce_reject_code"></a>`multi_recipient_bounce_reject_code`

Data type: `Optional[String]`



##### <a name="mydestination"></a>`mydestination`

Data type: `Optional[Array[String, 1]]`



##### <a name="mydomain"></a>`mydomain`

Data type: `Optional[String]`



##### <a name="myhostname"></a>`myhostname`

Data type: `Optional[String]`



##### <a name="mynetworks"></a>`mynetworks`

Data type: `Optional[Array[String, 1]]`



##### <a name="mynetworks_style"></a>`mynetworks_style`

Data type: `Optional[String]`



##### <a name="myorigin"></a>`myorigin`

Data type: `Optional[String]`



##### <a name="nested_header_checks"></a>`nested_header_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="newaliases_path"></a>`newaliases_path`

Data type: `Optional[String]`



##### <a name="non_fqdn_reject_code"></a>`non_fqdn_reject_code`

Data type: `Optional[String]`



##### <a name="non_smtpd_milters"></a>`non_smtpd_milters`

Data type: `Optional[Array[String, 1]]`



##### <a name="notify_classes"></a>`notify_classes`

Data type: `Optional[Array[String, 1]]`



##### <a name="owner_request_special"></a>`owner_request_special`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="parent_domain_matches_subdomains"></a>`parent_domain_matches_subdomains`

Data type: `Optional[Array[String, 1]]`



##### <a name="permit_mx_backup_networks"></a>`permit_mx_backup_networks`

Data type: `Optional[Array[String, 1]]`



##### <a name="pickup_service_name"></a>`pickup_service_name`

Data type: `Optional[String]`



##### <a name="plaintext_reject_code"></a>`plaintext_reject_code`

Data type: `Optional[String]`



##### <a name="postmulti_control_commands"></a>`postmulti_control_commands`

Data type: `Optional[Array[String, 1]]`



##### <a name="postmulti_start_commands"></a>`postmulti_start_commands`

Data type: `Optional[Array[String, 1]]`



##### <a name="postmulti_stop_commands"></a>`postmulti_stop_commands`

Data type: `Optional[Array[String, 1]]`



##### <a name="postscreen_access_list"></a>`postscreen_access_list`

Data type: `Optional[Array[String, 1]]`



##### <a name="postscreen_bare_newline_action"></a>`postscreen_bare_newline_action`

Data type: `Optional[String]`



##### <a name="postscreen_bare_newline_enable"></a>`postscreen_bare_newline_enable`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="postscreen_bare_newline_ttl"></a>`postscreen_bare_newline_ttl`

Data type: `Optional[String]`



##### <a name="postscreen_blacklist_action"></a>`postscreen_blacklist_action`

Data type: `Optional[String]`



##### <a name="postscreen_cache_cleanup_interval"></a>`postscreen_cache_cleanup_interval`

Data type: `Optional[String]`



##### <a name="postscreen_cache_map"></a>`postscreen_cache_map`

Data type: `Optional[String]`



##### <a name="postscreen_cache_retention_time"></a>`postscreen_cache_retention_time`

Data type: `Optional[String]`



##### <a name="postscreen_client_connection_count_limit"></a>`postscreen_client_connection_count_limit`

Data type: `Optional[String]`



##### <a name="postscreen_command_count_limit"></a>`postscreen_command_count_limit`

Data type: `Optional[String]`



##### <a name="postscreen_command_filter"></a>`postscreen_command_filter`

Data type: `Optional[String]`



##### <a name="postscreen_command_time_limit"></a>`postscreen_command_time_limit`

Data type: `Optional[String]`



##### <a name="postscreen_disable_vrfy_command"></a>`postscreen_disable_vrfy_command`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="postscreen_discard_ehlo_keyword_address_maps"></a>`postscreen_discard_ehlo_keyword_address_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="postscreen_discard_ehlo_keywords"></a>`postscreen_discard_ehlo_keywords`

Data type: `Optional[Array[String, 1]]`



##### <a name="postscreen_dnsbl_action"></a>`postscreen_dnsbl_action`

Data type: `Optional[String]`



##### <a name="postscreen_dnsbl_reply_map"></a>`postscreen_dnsbl_reply_map`

Data type: `Optional[String]`



##### <a name="postscreen_dnsbl_sites"></a>`postscreen_dnsbl_sites`

Data type: `Optional[Array[String, 1]]`



##### <a name="postscreen_dnsbl_threshold"></a>`postscreen_dnsbl_threshold`

Data type: `Optional[String]`



##### <a name="postscreen_dnsbl_ttl"></a>`postscreen_dnsbl_ttl`

Data type: `Optional[String]`



##### <a name="postscreen_enforce_tls"></a>`postscreen_enforce_tls`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="postscreen_expansion_filter"></a>`postscreen_expansion_filter`

Data type: `Optional[String]`



##### <a name="postscreen_forbidden_commands"></a>`postscreen_forbidden_commands`

Data type: `Optional[Array[String, 1]]`



##### <a name="postscreen_greet_action"></a>`postscreen_greet_action`

Data type: `Optional[String]`



##### <a name="postscreen_greet_banner"></a>`postscreen_greet_banner`

Data type: `Optional[String]`



##### <a name="postscreen_greet_ttl"></a>`postscreen_greet_ttl`

Data type: `Optional[String]`



##### <a name="postscreen_greet_wait"></a>`postscreen_greet_wait`

Data type: `Optional[String]`



##### <a name="postscreen_helo_required"></a>`postscreen_helo_required`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="postscreen_non_smtp_command_action"></a>`postscreen_non_smtp_command_action`

Data type: `Optional[String]`



##### <a name="postscreen_non_smtp_command_enable"></a>`postscreen_non_smtp_command_enable`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="postscreen_non_smtp_command_ttl"></a>`postscreen_non_smtp_command_ttl`

Data type: `Optional[String]`



##### <a name="postscreen_pipelining_action"></a>`postscreen_pipelining_action`

Data type: `Optional[String]`



##### <a name="postscreen_pipelining_enable"></a>`postscreen_pipelining_enable`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="postscreen_pipelining_ttl"></a>`postscreen_pipelining_ttl`

Data type: `Optional[String]`



##### <a name="postscreen_post_queue_limit"></a>`postscreen_post_queue_limit`

Data type: `Optional[String]`



##### <a name="postscreen_pre_queue_limit"></a>`postscreen_pre_queue_limit`

Data type: `Optional[String]`



##### <a name="postscreen_reject_footer"></a>`postscreen_reject_footer`

Data type: `Optional[String]`



##### <a name="postscreen_tls_security_level"></a>`postscreen_tls_security_level`

Data type: `Optional[String]`



##### <a name="postscreen_upstream_proxy_protocol"></a>`postscreen_upstream_proxy_protocol`

Data type: `Optional[String]`



##### <a name="postscreen_upstream_proxy_timeout"></a>`postscreen_upstream_proxy_timeout`

Data type: `Optional[String]`



##### <a name="postscreen_use_tls"></a>`postscreen_use_tls`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="postscreen_watchdog_timeout"></a>`postscreen_watchdog_timeout`

Data type: `Optional[String]`



##### <a name="postscreen_whitelist_interfaces"></a>`postscreen_whitelist_interfaces`

Data type: `Optional[Array[String, 1]]`



##### <a name="prepend_delivered_header"></a>`prepend_delivered_header`

Data type: `Optional[Array[String, 1]]`



##### <a name="process_id_directory"></a>`process_id_directory`

Data type: `Optional[String]`



##### <a name="propagate_unmatched_extensions"></a>`propagate_unmatched_extensions`

Data type: `Optional[Array[String, 1]]`



##### <a name="proxy_interfaces"></a>`proxy_interfaces`

Data type: `Optional[Array[String, 1]]`



##### <a name="proxy_read_maps"></a>`proxy_read_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="proxy_write_maps"></a>`proxy_write_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="proxymap_service_name"></a>`proxymap_service_name`

Data type: `Optional[String]`



##### <a name="proxywrite_service_name"></a>`proxywrite_service_name`

Data type: `Optional[String]`



##### <a name="qmgr_clog_warn_time"></a>`qmgr_clog_warn_time`

Data type: `Optional[String]`



##### <a name="qmgr_daemon_timeout"></a>`qmgr_daemon_timeout`

Data type: `Optional[String]`



##### <a name="qmgr_fudge_factor"></a>`qmgr_fudge_factor`

Data type: `Optional[String]`



##### <a name="qmgr_ipc_timeout"></a>`qmgr_ipc_timeout`

Data type: `Optional[String]`



##### <a name="qmgr_message_active_limit"></a>`qmgr_message_active_limit`

Data type: `Optional[String]`



##### <a name="qmgr_message_recipient_limit"></a>`qmgr_message_recipient_limit`

Data type: `Optional[String]`



##### <a name="qmgr_message_recipient_minimum"></a>`qmgr_message_recipient_minimum`

Data type: `Optional[String]`



##### <a name="qmqpd_authorized_clients"></a>`qmqpd_authorized_clients`

Data type: `Optional[Array[String, 1]]`



##### <a name="qmqpd_client_port_logging"></a>`qmqpd_client_port_logging`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="qmqpd_error_delay"></a>`qmqpd_error_delay`

Data type: `Optional[String]`



##### <a name="qmqpd_timeout"></a>`qmqpd_timeout`

Data type: `Optional[String]`



##### <a name="queue_directory"></a>`queue_directory`

Data type: `Optional[String]`



##### <a name="queue_file_attribute_count_limit"></a>`queue_file_attribute_count_limit`

Data type: `Optional[String]`



##### <a name="queue_minfree"></a>`queue_minfree`

Data type: `Optional[String]`



##### <a name="queue_run_delay"></a>`queue_run_delay`

Data type: `Optional[String]`



##### <a name="queue_service_name"></a>`queue_service_name`

Data type: `Optional[String]`



##### <a name="rbl_reply_maps"></a>`rbl_reply_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="readme_directory"></a>`readme_directory`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="receive_override_options"></a>`receive_override_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="recipient_bcc_maps"></a>`recipient_bcc_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="recipient_canonical_classes"></a>`recipient_canonical_classes`

Data type: `Optional[Array[String, 1]]`



##### <a name="recipient_canonical_maps"></a>`recipient_canonical_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="recipient_delimiter"></a>`recipient_delimiter`

Data type: `Optional[String]`



##### <a name="reject_code"></a>`reject_code`

Data type: `Optional[String]`



##### <a name="reject_tempfail_action"></a>`reject_tempfail_action`

Data type: `Optional[String]`



##### <a name="relay_clientcerts"></a>`relay_clientcerts`

Data type: `Optional[Array[String, 1]]`



##### <a name="relay_domains"></a>`relay_domains`

Data type: `Optional[Array[String, 1]]`



##### <a name="relay_domains_reject_code"></a>`relay_domains_reject_code`

Data type: `Optional[String]`



##### <a name="relay_recipient_maps"></a>`relay_recipient_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="relay_transport"></a>`relay_transport`

Data type: `Optional[String]`



##### <a name="relayhost"></a>`relayhost`

Data type: `Optional[String]`



##### <a name="relocated_maps"></a>`relocated_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="remote_header_rewrite_domain"></a>`remote_header_rewrite_domain`

Data type: `Optional[String]`



##### <a name="require_home_directory"></a>`require_home_directory`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="reset_owner_alias"></a>`reset_owner_alias`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="resolve_dequoted_address"></a>`resolve_dequoted_address`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="resolve_null_domain"></a>`resolve_null_domain`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="resolve_numeric_domain"></a>`resolve_numeric_domain`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="rewrite_service_name"></a>`rewrite_service_name`

Data type: `Optional[String]`



##### <a name="sample_directory"></a>`sample_directory`

Data type: `Optional[String]`



##### <a name="send_cyrus_sasl_authzid"></a>`send_cyrus_sasl_authzid`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="sender_bcc_maps"></a>`sender_bcc_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="sender_canonical_classes"></a>`sender_canonical_classes`

Data type: `Optional[Array[String, 1]]`



##### <a name="sender_canonical_maps"></a>`sender_canonical_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="sender_dependent_default_transport_maps"></a>`sender_dependent_default_transport_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="sender_dependent_relayhost_maps"></a>`sender_dependent_relayhost_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="sendmail_fix_line_endings"></a>`sendmail_fix_line_endings`

Data type: `Optional[String]`



##### <a name="sendmail_path"></a>`sendmail_path`

Data type: `Optional[String]`



##### <a name="service_throttle_time"></a>`service_throttle_time`

Data type: `Optional[String]`



##### <a name="setgid_group"></a>`setgid_group`

Data type: `Optional[String]`



##### <a name="shlib_directory"></a>`shlib_directory`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="show_user_unknown_table_name"></a>`show_user_unknown_table_name`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="showq_service_name"></a>`showq_service_name`

Data type: `Optional[String]`



##### <a name="smtp_address_preference"></a>`smtp_address_preference`

Data type: `Optional[String]`



##### <a name="smtp_always_send_ehlo"></a>`smtp_always_send_ehlo`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_bind_address"></a>`smtp_bind_address`

Data type: `Optional[String]`



##### <a name="smtp_bind_address6"></a>`smtp_bind_address6`

Data type: `Optional[String]`



##### <a name="smtp_body_checks"></a>`smtp_body_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_cname_overrides_servername"></a>`smtp_cname_overrides_servername`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_connect_timeout"></a>`smtp_connect_timeout`

Data type: `Optional[String]`



##### <a name="smtp_connection_cache_destinations"></a>`smtp_connection_cache_destinations`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_connection_cache_on_demand"></a>`smtp_connection_cache_on_demand`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_connection_cache_time_limit"></a>`smtp_connection_cache_time_limit`

Data type: `Optional[String]`



##### <a name="smtp_connection_reuse_time_limit"></a>`smtp_connection_reuse_time_limit`

Data type: `Optional[String]`



##### <a name="smtp_data_done_timeout"></a>`smtp_data_done_timeout`

Data type: `Optional[String]`



##### <a name="smtp_data_init_timeout"></a>`smtp_data_init_timeout`

Data type: `Optional[String]`



##### <a name="smtp_data_xfer_timeout"></a>`smtp_data_xfer_timeout`

Data type: `Optional[String]`



##### <a name="smtp_defer_if_no_mx_address_found"></a>`smtp_defer_if_no_mx_address_found`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_discard_ehlo_keyword_address_maps"></a>`smtp_discard_ehlo_keyword_address_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_discard_ehlo_keywords"></a>`smtp_discard_ehlo_keywords`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_dns_resolver_options"></a>`smtp_dns_resolver_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_enforce_tls"></a>`smtp_enforce_tls`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_fallback_relay"></a>`smtp_fallback_relay`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_generic_maps"></a>`smtp_generic_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_header_checks"></a>`smtp_header_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_helo_name"></a>`smtp_helo_name`

Data type: `Optional[String]`



##### <a name="smtp_helo_timeout"></a>`smtp_helo_timeout`

Data type: `Optional[String]`



##### <a name="smtp_host_lookup"></a>`smtp_host_lookup`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_line_length_limit"></a>`smtp_line_length_limit`

Data type: `Optional[String]`



##### <a name="smtp_mail_timeout"></a>`smtp_mail_timeout`

Data type: `Optional[String]`



##### <a name="smtp_mime_header_checks"></a>`smtp_mime_header_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_mx_address_limit"></a>`smtp_mx_address_limit`

Data type: `Optional[String]`



##### <a name="smtp_mx_session_limit"></a>`smtp_mx_session_limit`

Data type: `Optional[String]`



##### <a name="smtp_nested_header_checks"></a>`smtp_nested_header_checks`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_never_send_ehlo"></a>`smtp_never_send_ehlo`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_per_record_deadline"></a>`smtp_per_record_deadline`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_pix_workaround_delay_time"></a>`smtp_pix_workaround_delay_time`

Data type: `Optional[String]`



##### <a name="smtp_pix_workaround_maps"></a>`smtp_pix_workaround_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_pix_workaround_threshold_time"></a>`smtp_pix_workaround_threshold_time`

Data type: `Optional[String]`



##### <a name="smtp_pix_workarounds"></a>`smtp_pix_workarounds`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_quit_timeout"></a>`smtp_quit_timeout`

Data type: `Optional[String]`



##### <a name="smtp_quote_rfc821_envelope"></a>`smtp_quote_rfc821_envelope`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_randomize_addresses"></a>`smtp_randomize_addresses`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_rcpt_timeout"></a>`smtp_rcpt_timeout`

Data type: `Optional[String]`



##### <a name="smtp_reply_filter"></a>`smtp_reply_filter`

Data type: `Optional[String]`



##### <a name="smtp_rset_timeout"></a>`smtp_rset_timeout`

Data type: `Optional[String]`



##### <a name="smtp_sasl_auth_cache_name"></a>`smtp_sasl_auth_cache_name`

Data type: `Optional[String]`



##### <a name="smtp_sasl_auth_cache_time"></a>`smtp_sasl_auth_cache_time`

Data type: `Optional[String]`



##### <a name="smtp_sasl_auth_enable"></a>`smtp_sasl_auth_enable`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_sasl_auth_soft_bounce"></a>`smtp_sasl_auth_soft_bounce`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_sasl_mechanism_filter"></a>`smtp_sasl_mechanism_filter`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_sasl_password_maps"></a>`smtp_sasl_password_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_sasl_path"></a>`smtp_sasl_path`

Data type: `Optional[String]`



##### <a name="smtp_sasl_security_options"></a>`smtp_sasl_security_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_sasl_tls_security_options"></a>`smtp_sasl_tls_security_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_sasl_tls_verified_security_options"></a>`smtp_sasl_tls_verified_security_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_sasl_type"></a>`smtp_sasl_type`

Data type: `Optional[String]`



##### <a name="smtp_send_dummy_mail_auth"></a>`smtp_send_dummy_mail_auth`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_send_xforward_command"></a>`smtp_send_xforward_command`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_sender_dependent_authentication"></a>`smtp_sender_dependent_authentication`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_skip_5xx_greeting"></a>`smtp_skip_5xx_greeting`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_skip_quit_response"></a>`smtp_skip_quit_response`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_starttls_timeout"></a>`smtp_starttls_timeout`

Data type: `Optional[String]`



##### <a name="smtp_tls_cafile"></a>`smtp_tls_cafile`

Data type: `Optional[String]`



##### <a name="smtp_tls_capath"></a>`smtp_tls_capath`

Data type: `Optional[String]`



##### <a name="smtp_tls_block_early_mail_reply"></a>`smtp_tls_block_early_mail_reply`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_tls_cert_file"></a>`smtp_tls_cert_file`

Data type: `Optional[String]`



##### <a name="smtp_tls_ciphers"></a>`smtp_tls_ciphers`

Data type: `Optional[String]`



##### <a name="smtp_tls_dcert_file"></a>`smtp_tls_dcert_file`

Data type: `Optional[String]`



##### <a name="smtp_tls_dkey_file"></a>`smtp_tls_dkey_file`

Data type: `Optional[String]`



##### <a name="smtp_tls_eccert_file"></a>`smtp_tls_eccert_file`

Data type: `Optional[String]`



##### <a name="smtp_tls_eckey_file"></a>`smtp_tls_eckey_file`

Data type: `Optional[String]`



##### <a name="smtp_tls_enforce_peername"></a>`smtp_tls_enforce_peername`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_tls_exclude_ciphers"></a>`smtp_tls_exclude_ciphers`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_tls_fingerprint_cert_match"></a>`smtp_tls_fingerprint_cert_match`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_tls_fingerprint_digest"></a>`smtp_tls_fingerprint_digest`

Data type: `Optional[String]`



##### <a name="smtp_tls_key_file"></a>`smtp_tls_key_file`

Data type: `Optional[String]`



##### <a name="smtp_tls_loglevel"></a>`smtp_tls_loglevel`

Data type: `Optional[String]`



##### <a name="smtp_tls_mandatory_ciphers"></a>`smtp_tls_mandatory_ciphers`

Data type: `Optional[String]`



##### <a name="smtp_tls_mandatory_exclude_ciphers"></a>`smtp_tls_mandatory_exclude_ciphers`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_tls_mandatory_protocols"></a>`smtp_tls_mandatory_protocols`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_tls_note_starttls_offer"></a>`smtp_tls_note_starttls_offer`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_tls_per_site"></a>`smtp_tls_per_site`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_tls_policy_maps"></a>`smtp_tls_policy_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_tls_protocols"></a>`smtp_tls_protocols`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_tls_scert_verifydepth"></a>`smtp_tls_scert_verifydepth`

Data type: `Optional[String]`



##### <a name="smtp_tls_secure_cert_match"></a>`smtp_tls_secure_cert_match`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_tls_security_level"></a>`smtp_tls_security_level`

Data type: `Optional[String]`



##### <a name="smtp_tls_session_cache_database"></a>`smtp_tls_session_cache_database`

Data type: `Optional[String]`



##### <a name="smtp_tls_session_cache_timeout"></a>`smtp_tls_session_cache_timeout`

Data type: `Optional[String]`



##### <a name="smtp_tls_verify_cert_match"></a>`smtp_tls_verify_cert_match`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtp_use_tls"></a>`smtp_use_tls`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtp_xforward_timeout"></a>`smtp_xforward_timeout`

Data type: `Optional[String]`



##### <a name="smtpd_authorized_verp_clients"></a>`smtpd_authorized_verp_clients`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_authorized_xclient_hosts"></a>`smtpd_authorized_xclient_hosts`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_authorized_xforward_hosts"></a>`smtpd_authorized_xforward_hosts`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_banner"></a>`smtpd_banner`

Data type: `Optional[String]`



##### <a name="smtpd_client_connection_count_limit"></a>`smtpd_client_connection_count_limit`

Data type: `Optional[String]`



##### <a name="smtpd_client_connection_rate_limit"></a>`smtpd_client_connection_rate_limit`

Data type: `Optional[String]`



##### <a name="smtpd_client_event_limit_exceptions"></a>`smtpd_client_event_limit_exceptions`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_client_message_rate_limit"></a>`smtpd_client_message_rate_limit`

Data type: `Optional[String]`



##### <a name="smtpd_client_new_tls_session_rate_limit"></a>`smtpd_client_new_tls_session_rate_limit`

Data type: `Optional[String]`



##### <a name="smtpd_client_port_logging"></a>`smtpd_client_port_logging`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_client_recipient_rate_limit"></a>`smtpd_client_recipient_rate_limit`

Data type: `Optional[String]`



##### <a name="smtpd_client_restrictions"></a>`smtpd_client_restrictions`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_command_filter"></a>`smtpd_command_filter`

Data type: `Optional[String]`



##### <a name="smtpd_data_restrictions"></a>`smtpd_data_restrictions`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_delay_open_until_valid_rcpt"></a>`smtpd_delay_open_until_valid_rcpt`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_delay_reject"></a>`smtpd_delay_reject`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_discard_ehlo_keyword_address_maps"></a>`smtpd_discard_ehlo_keyword_address_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_discard_ehlo_keywords"></a>`smtpd_discard_ehlo_keywords`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_end_of_data_restrictions"></a>`smtpd_end_of_data_restrictions`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_enforce_tls"></a>`smtpd_enforce_tls`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_error_sleep_time"></a>`smtpd_error_sleep_time`

Data type: `Optional[String]`



##### <a name="smtpd_etrn_restrictions"></a>`smtpd_etrn_restrictions`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_expansion_filter"></a>`smtpd_expansion_filter`

Data type: `Optional[String]`



##### <a name="smtpd_forbidden_commands"></a>`smtpd_forbidden_commands`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_hard_error_limit"></a>`smtpd_hard_error_limit`

Data type: `Optional[String]`



##### <a name="smtpd_helo_required"></a>`smtpd_helo_required`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_helo_restrictions"></a>`smtpd_helo_restrictions`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_history_flush_threshold"></a>`smtpd_history_flush_threshold`

Data type: `Optional[String]`



##### <a name="smtpd_junk_command_limit"></a>`smtpd_junk_command_limit`

Data type: `Optional[String]`



##### <a name="smtpd_log_access_permit_actions"></a>`smtpd_log_access_permit_actions`

Data type: `Optional[String]`



##### <a name="smtpd_milters"></a>`smtpd_milters`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_noop_commands"></a>`smtpd_noop_commands`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_null_access_lookup_key"></a>`smtpd_null_access_lookup_key`

Data type: `Optional[String]`



##### <a name="smtpd_peername_lookup"></a>`smtpd_peername_lookup`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_per_record_deadline"></a>`smtpd_per_record_deadline`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_policy_service_max_idle"></a>`smtpd_policy_service_max_idle`

Data type: `Optional[String]`



##### <a name="smtpd_policy_service_max_ttl"></a>`smtpd_policy_service_max_ttl`

Data type: `Optional[String]`



##### <a name="smtpd_policy_service_timeout"></a>`smtpd_policy_service_timeout`

Data type: `Optional[String]`



##### <a name="smtpd_proxy_ehlo"></a>`smtpd_proxy_ehlo`

Data type: `Optional[String]`



##### <a name="smtpd_proxy_filter"></a>`smtpd_proxy_filter`

Data type: `Optional[String]`



##### <a name="smtpd_proxy_options"></a>`smtpd_proxy_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_proxy_timeout"></a>`smtpd_proxy_timeout`

Data type: `Optional[String]`



##### <a name="smtpd_recipient_limit"></a>`smtpd_recipient_limit`

Data type: `Optional[String]`



##### <a name="smtpd_recipient_overshoot_limit"></a>`smtpd_recipient_overshoot_limit`

Data type: `Optional[String]`



##### <a name="smtpd_recipient_restrictions"></a>`smtpd_recipient_restrictions`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_reject_footer"></a>`smtpd_reject_footer`

Data type: `Optional[String]`



##### <a name="smtpd_reject_unlisted_recipient"></a>`smtpd_reject_unlisted_recipient`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_reject_unlisted_sender"></a>`smtpd_reject_unlisted_sender`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_relay_restrictions"></a>`smtpd_relay_restrictions`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_restriction_classes"></a>`smtpd_restriction_classes`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_sasl_auth_enable"></a>`smtpd_sasl_auth_enable`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_sasl_authenticated_header"></a>`smtpd_sasl_authenticated_header`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_sasl_exceptions_networks"></a>`smtpd_sasl_exceptions_networks`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_sasl_local_domain"></a>`smtpd_sasl_local_domain`

Data type: `Optional[String]`



##### <a name="smtpd_sasl_path"></a>`smtpd_sasl_path`

Data type: `Optional[String]`



##### <a name="smtpd_sasl_security_options"></a>`smtpd_sasl_security_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_sasl_tls_security_options"></a>`smtpd_sasl_tls_security_options`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_sasl_type"></a>`smtpd_sasl_type`

Data type: `Optional[String]`



##### <a name="smtpd_sender_login_maps"></a>`smtpd_sender_login_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_sender_restrictions"></a>`smtpd_sender_restrictions`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_service_name"></a>`smtpd_service_name`

Data type: `Optional[String]`



##### <a name="smtpd_soft_error_limit"></a>`smtpd_soft_error_limit`

Data type: `Optional[String]`



##### <a name="smtpd_starttls_timeout"></a>`smtpd_starttls_timeout`

Data type: `Optional[String]`



##### <a name="smtpd_timeout"></a>`smtpd_timeout`

Data type: `Optional[String]`



##### <a name="smtpd_tls_cafile"></a>`smtpd_tls_cafile`

Data type: `Optional[String]`



##### <a name="smtpd_tls_capath"></a>`smtpd_tls_capath`

Data type: `Optional[String]`



##### <a name="smtpd_tls_always_issue_session_ids"></a>`smtpd_tls_always_issue_session_ids`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_tls_ask_ccert"></a>`smtpd_tls_ask_ccert`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_tls_auth_only"></a>`smtpd_tls_auth_only`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_tls_ccert_verifydepth"></a>`smtpd_tls_ccert_verifydepth`

Data type: `Optional[String]`



##### <a name="smtpd_tls_cert_file"></a>`smtpd_tls_cert_file`

Data type: `Optional[String]`



##### <a name="smtpd_tls_ciphers"></a>`smtpd_tls_ciphers`

Data type: `Optional[String]`



##### <a name="smtpd_tls_dcert_file"></a>`smtpd_tls_dcert_file`

Data type: `Optional[String]`



##### <a name="smtpd_tls_dh1024_param_file"></a>`smtpd_tls_dh1024_param_file`

Data type: `Optional[String]`



##### <a name="smtpd_tls_dh512_param_file"></a>`smtpd_tls_dh512_param_file`

Data type: `Optional[String]`



##### <a name="smtpd_tls_dkey_file"></a>`smtpd_tls_dkey_file`

Data type: `Optional[String]`



##### <a name="smtpd_tls_eccert_file"></a>`smtpd_tls_eccert_file`

Data type: `Optional[String]`



##### <a name="smtpd_tls_eckey_file"></a>`smtpd_tls_eckey_file`

Data type: `Optional[String]`



##### <a name="smtpd_tls_eecdh_grade"></a>`smtpd_tls_eecdh_grade`

Data type: `Optional[String]`



##### <a name="smtpd_tls_exclude_ciphers"></a>`smtpd_tls_exclude_ciphers`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_tls_fingerprint_digest"></a>`smtpd_tls_fingerprint_digest`

Data type: `Optional[String]`



##### <a name="smtpd_tls_key_file"></a>`smtpd_tls_key_file`

Data type: `Optional[String]`



##### <a name="smtpd_tls_loglevel"></a>`smtpd_tls_loglevel`

Data type: `Optional[String]`



##### <a name="smtpd_tls_mandatory_ciphers"></a>`smtpd_tls_mandatory_ciphers`

Data type: `Optional[String]`



##### <a name="smtpd_tls_mandatory_exclude_ciphers"></a>`smtpd_tls_mandatory_exclude_ciphers`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_tls_mandatory_protocols"></a>`smtpd_tls_mandatory_protocols`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_tls_protocols"></a>`smtpd_tls_protocols`

Data type: `Optional[Array[String, 1]]`



##### <a name="smtpd_tls_received_header"></a>`smtpd_tls_received_header`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_tls_req_ccert"></a>`smtpd_tls_req_ccert`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_tls_security_level"></a>`smtpd_tls_security_level`

Data type: `Optional[String]`



##### <a name="smtpd_tls_session_cache_database"></a>`smtpd_tls_session_cache_database`

Data type: `Optional[String]`



##### <a name="smtpd_tls_session_cache_timeout"></a>`smtpd_tls_session_cache_timeout`

Data type: `Optional[String]`



##### <a name="smtpd_tls_wrappermode"></a>`smtpd_tls_wrappermode`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="smtpd_upstream_proxy_protocol"></a>`smtpd_upstream_proxy_protocol`

Data type: `Optional[String]`



##### <a name="smtpd_upstream_proxy_timeout"></a>`smtpd_upstream_proxy_timeout`

Data type: `Optional[String]`



##### <a name="smtpd_use_tls"></a>`smtpd_use_tls`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="soft_bounce"></a>`soft_bounce`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="stale_lock_time"></a>`stale_lock_time`

Data type: `Optional[String]`



##### <a name="strict_7bit_headers"></a>`strict_7bit_headers`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="strict_8bitmime"></a>`strict_8bitmime`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="strict_8bitmime_body"></a>`strict_8bitmime_body`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="strict_mailbox_ownership"></a>`strict_mailbox_ownership`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="strict_mime_encoding_domain"></a>`strict_mime_encoding_domain`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="strict_rfc821_envelopes"></a>`strict_rfc821_envelopes`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="sun_mailtool_compatibility"></a>`sun_mailtool_compatibility`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="swap_bangpath"></a>`swap_bangpath`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="syslog_facility"></a>`syslog_facility`

Data type: `Optional[String]`



##### <a name="syslog_name"></a>`syslog_name`

Data type: `Optional[String]`



##### <a name="tcp_windowsize"></a>`tcp_windowsize`

Data type: `Optional[String]`



##### <a name="tls_append_default_ca"></a>`tls_append_default_ca`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="tls_daemon_random_bytes"></a>`tls_daemon_random_bytes`

Data type: `Optional[String]`



##### <a name="tls_disable_workarounds"></a>`tls_disable_workarounds`

Data type: `Optional[Array[String, 1]]`



##### <a name="tls_eecdh_strong_curve"></a>`tls_eecdh_strong_curve`

Data type: `Optional[String]`



##### <a name="tls_eecdh_ultra_curve"></a>`tls_eecdh_ultra_curve`

Data type: `Optional[String]`



##### <a name="tls_export_cipherlist"></a>`tls_export_cipherlist`

Data type: `Optional[String]`



##### <a name="tls_high_cipherlist"></a>`tls_high_cipherlist`

Data type: `Optional[String]`



##### <a name="tls_legacy_public_key_fingerprints"></a>`tls_legacy_public_key_fingerprints`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="tls_low_cipherlist"></a>`tls_low_cipherlist`

Data type: `Optional[String]`



##### <a name="tls_medium_cipherlist"></a>`tls_medium_cipherlist`

Data type: `Optional[String]`



##### <a name="tls_null_cipherlist"></a>`tls_null_cipherlist`

Data type: `Optional[String]`



##### <a name="tls_preempt_cipherlist"></a>`tls_preempt_cipherlist`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="tls_random_bytes"></a>`tls_random_bytes`

Data type: `Optional[String]`



##### <a name="tls_random_exchange_name"></a>`tls_random_exchange_name`

Data type: `Optional[String]`



##### <a name="tls_random_prng_update_period"></a>`tls_random_prng_update_period`

Data type: `Optional[String]`



##### <a name="tls_random_reseed_period"></a>`tls_random_reseed_period`

Data type: `Optional[String]`



##### <a name="tls_random_source"></a>`tls_random_source`

Data type: `Optional[String]`



##### <a name="tlsproxy_enforce_tls"></a>`tlsproxy_enforce_tls`

Data type: `Optional[String]`



##### <a name="tlsproxy_service_name"></a>`tlsproxy_service_name`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_cafile"></a>`tlsproxy_tls_cafile`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_capath"></a>`tlsproxy_tls_capath`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_always_issue_session_ids"></a>`tlsproxy_tls_always_issue_session_ids`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="tlsproxy_tls_ask_ccert"></a>`tlsproxy_tls_ask_ccert`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="tlsproxy_tls_ccert_verifydepth"></a>`tlsproxy_tls_ccert_verifydepth`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_cert_file"></a>`tlsproxy_tls_cert_file`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_ciphers"></a>`tlsproxy_tls_ciphers`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_dcert_file"></a>`tlsproxy_tls_dcert_file`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_dh1024_param_file"></a>`tlsproxy_tls_dh1024_param_file`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_dh512_param_file"></a>`tlsproxy_tls_dh512_param_file`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_dkey_file"></a>`tlsproxy_tls_dkey_file`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_eccert_file"></a>`tlsproxy_tls_eccert_file`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_eckey_file"></a>`tlsproxy_tls_eckey_file`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_eecdh_grade"></a>`tlsproxy_tls_eecdh_grade`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_exclude_ciphers"></a>`tlsproxy_tls_exclude_ciphers`

Data type: `Optional[Array[String, 1]]`



##### <a name="tlsproxy_tls_fingerprint_digest"></a>`tlsproxy_tls_fingerprint_digest`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_key_file"></a>`tlsproxy_tls_key_file`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_loglevel"></a>`tlsproxy_tls_loglevel`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_mandatory_ciphers"></a>`tlsproxy_tls_mandatory_ciphers`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_mandatory_exclude_ciphers"></a>`tlsproxy_tls_mandatory_exclude_ciphers`

Data type: `Optional[Array[String, 1]]`



##### <a name="tlsproxy_tls_mandatory_protocols"></a>`tlsproxy_tls_mandatory_protocols`

Data type: `Optional[Array[String, 1]]`



##### <a name="tlsproxy_tls_protocols"></a>`tlsproxy_tls_protocols`

Data type: `Optional[Array[String, 1]]`



##### <a name="tlsproxy_tls_req_ccert"></a>`tlsproxy_tls_req_ccert`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="tlsproxy_tls_security_level"></a>`tlsproxy_tls_security_level`

Data type: `Optional[String]`



##### <a name="tlsproxy_tls_session_cache_timeout"></a>`tlsproxy_tls_session_cache_timeout`

Data type: `Optional[String]`



##### <a name="tlsproxy_use_tls"></a>`tlsproxy_use_tls`

Data type: `Optional[Variant[Boolean, String]]`



##### <a name="tlsproxy_watchdog_timeout"></a>`tlsproxy_watchdog_timeout`

Data type: `Optional[String]`



##### <a name="trace_service_name"></a>`trace_service_name`

Data type: `Optional[String]`



##### <a name="transport_maps"></a>`transport_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="transport_retry_time"></a>`transport_retry_time`

Data type: `Optional[String]`



##### <a name="trigger_timeout"></a>`trigger_timeout`

Data type: `Optional[String]`



##### <a name="undisclosed_recipients_header"></a>`undisclosed_recipients_header`

Data type: `Optional[String]`



##### <a name="unknown_address_reject_code"></a>`unknown_address_reject_code`

Data type: `Optional[String]`



##### <a name="unknown_address_tempfail_action"></a>`unknown_address_tempfail_action`

Data type: `Optional[String]`



##### <a name="unknown_client_reject_code"></a>`unknown_client_reject_code`

Data type: `Optional[String]`



##### <a name="unknown_helo_hostname_tempfail_action"></a>`unknown_helo_hostname_tempfail_action`

Data type: `Optional[String]`



##### <a name="unknown_hostname_reject_code"></a>`unknown_hostname_reject_code`

Data type: `Optional[String]`



##### <a name="unknown_local_recipient_reject_code"></a>`unknown_local_recipient_reject_code`

Data type: `Optional[String]`



##### <a name="unknown_relay_recipient_reject_code"></a>`unknown_relay_recipient_reject_code`

Data type: `Optional[String]`



##### <a name="unknown_virtual_alias_reject_code"></a>`unknown_virtual_alias_reject_code`

Data type: `Optional[String]`



##### <a name="unknown_virtual_mailbox_reject_code"></a>`unknown_virtual_mailbox_reject_code`

Data type: `Optional[String]`



##### <a name="unverified_recipient_defer_code"></a>`unverified_recipient_defer_code`

Data type: `Optional[String]`



##### <a name="unverified_recipient_reject_code"></a>`unverified_recipient_reject_code`

Data type: `Optional[String]`



##### <a name="unverified_recipient_reject_reason"></a>`unverified_recipient_reject_reason`

Data type: `Optional[String]`



##### <a name="unverified_recipient_tempfail_action"></a>`unverified_recipient_tempfail_action`

Data type: `Optional[String]`



##### <a name="unverified_sender_defer_code"></a>`unverified_sender_defer_code`

Data type: `Optional[String]`



##### <a name="unverified_sender_reject_code"></a>`unverified_sender_reject_code`

Data type: `Optional[String]`



##### <a name="unverified_sender_reject_reason"></a>`unverified_sender_reject_reason`

Data type: `Optional[String]`



##### <a name="unverified_sender_tempfail_action"></a>`unverified_sender_tempfail_action`

Data type: `Optional[String]`



##### <a name="verp_delimiter_filter"></a>`verp_delimiter_filter`

Data type: `Optional[String]`



##### <a name="virtual_alias_domains"></a>`virtual_alias_domains`

Data type: `Optional[Array[String, 1]]`



##### <a name="virtual_alias_expansion_limit"></a>`virtual_alias_expansion_limit`

Data type: `Optional[String]`



##### <a name="virtual_alias_maps"></a>`virtual_alias_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="virtual_alias_recursion_limit"></a>`virtual_alias_recursion_limit`

Data type: `Optional[String]`



##### <a name="virtual_gid_maps"></a>`virtual_gid_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="virtual_mailbox_base"></a>`virtual_mailbox_base`

Data type: `Optional[String]`



##### <a name="virtual_mailbox_domains"></a>`virtual_mailbox_domains`

Data type: `Optional[Array[String, 1]]`



##### <a name="virtual_mailbox_limit"></a>`virtual_mailbox_limit`

Data type: `Optional[String]`



##### <a name="virtual_mailbox_lock"></a>`virtual_mailbox_lock`

Data type: `Optional[Array[String, 1]]`



##### <a name="virtual_mailbox_maps"></a>`virtual_mailbox_maps`

Data type: `Optional[Array[String, 1]]`



##### <a name="virtual_minimum_uid"></a>`virtual_minimum_uid`

Data type: `Optional[String]`



##### <a name="virtual_transport"></a>`virtual_transport`

Data type: `Optional[String]`



##### <a name="virtual_uid_maps"></a>`virtual_uid_maps`

Data type: `Optional[Array[String, 1]]`



### <a name="postfixconfig"></a>`postfix::config`

The postfix::config class.

### <a name="postfixinstall"></a>`postfix::install`

The postfix::install class.

### <a name="postfixservice"></a>`postfix::service`

The postfix::service class.

## Defined types

### <a name="postfixlookupdatabase"></a>`postfix::lookup::database`

Define lookup tables using static database files.

* **Since** 1.0.0

* **See also**
  * puppet_classes::postfix
    * postfix

#### Examples

##### Define a `transport(5)` table

```puppet
postfix::lookup::database { '/etc/postfix/transport':
  content => @(EOS/L),
    example.com :
    | EOS
  type    => 'hash',
}
```

##### Manage the `aliases(5)` table with `mailalias` resources

```puppet
postfix::lookup::database { '/etc/aliases':
  type => 'hash',
}
Mailalias <||> -> Postfix::Lookup::Database['/etc/aliases']
```

#### Parameters

The following parameters are available in the `postfix::lookup::database` defined type:

* [`ensure`](#ensure)
* [`path`](#path)
* [`type`](#type)
* [`content`](#content)
* [`source`](#source)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `'present'`

##### <a name="path"></a>`path`

Data type: `Stdlib::Absolutepath`



Default value: `$title`

##### <a name="type"></a>`type`

Data type: `Postfix::Type::Lookup::Database`



Default value: `$postfix::default_database_type`

##### <a name="content"></a>`content`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="source"></a>`source`

Data type: `Optional[String]`



Default value: ``undef``

### <a name="postfixlookupldap"></a>`postfix::lookup::ldap`

Define an LDAP lookup table.

* **Since** 1.0.0

* **See also**
  * puppet_classes::postfix
    * postfix

#### Examples

##### Configure Postfix for virtual mailbox hosting using LDAP to provide the various lookup tables

```puppet
class { 'postfix':
  virtual_mailbox_base    => '/var/mail/vhosts',
  virtual_mailbox_domains => ['ldap:/etc/postfix/virtualdomains.cf'],
  virtual_mailbox_maps    => ['ldap:/etc/postfix/virtualrecipients.cf'],
  virtual_minimum_uid     => 100,
  virtual_uid_maps        => 'static:5000',
  virtual_gid_maps        => 'static:5000',
}

# Specify connection defaults to enable sharing as per LDAP_README
Postfix::Lookup::Ldap {
  server_host => ['ldap://192.0.2.1'],
  search_base => 'dc=example,dc=com',
  bind_dn     => 'cn=Manager,dc=example,dc=com',
  bind_pw     => 'secret',
  version     => 3,
}

postfix::lookup::ldap { '/etc/postfix/virtualdomains.cf':
  query_filter     => '(associatedDomain=%s)',
  result_attribute => ['associatedDomain'],
}

postfix::lookup::ldap { '/etc/postfix/virtualrecipients.cf':
  query_filter     => '(mail=%s)',
  result_attribute => ['mail'],
}
```

#### Parameters

The following parameters are available in the `postfix::lookup::ldap` defined type:

* [`search_base`](#search_base)
* [`path`](#path)
* [`ensure`](#ensure)
* [`server_host`](#server_host)
* [`server_port`](#server_port)
* [`timeout`](#timeout)
* [`query_filter`](#query_filter)
* [`result_format`](#result_format)
* [`domain`](#domain)
* [`result_attribute`](#result_attribute)
* [`special_result_attribute`](#special_result_attribute)
* [`terminal_result_attribute`](#terminal_result_attribute)
* [`leaf_result_attribute`](#leaf_result_attribute)
* [`scope`](#scope)
* [`bind`](#bind)
* [`bind_dn`](#bind_dn)
* [`bind_pw`](#bind_pw)
* [`recursion_limit`](#recursion_limit)
* [`expansion_limit`](#expansion_limit)
* [`size_limit`](#size_limit)
* [`dereference`](#dereference)
* [`chase_referrals`](#chase_referrals)
* [`version`](#version)
* [`debuglevel`](#debuglevel)
* [`sasl_mechs`](#sasl_mechs)
* [`sasl_realm`](#sasl_realm)
* [`sasl_authz_id`](#sasl_authz_id)
* [`sasl_minssf`](#sasl_minssf)
* [`start_tls`](#start_tls)
* [`tls_ca_cert_dir`](#tls_ca_cert_dir)
* [`tls_ca_cert_file`](#tls_ca_cert_file)
* [`tls_cert`](#tls_cert)
* [`tls_key`](#tls_key)
* [`tls_require_cert`](#tls_require_cert)
* [`tls_random_file`](#tls_random_file)
* [`tls_cipher_suite`](#tls_cipher_suite)

##### <a name="search_base"></a>`search_base`

Data type: `Bodgitlib::LDAP::DN`



##### <a name="path"></a>`path`

Data type: `Stdlib::Absolutepath`



Default value: `$title`

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `'present'`

##### <a name="server_host"></a>`server_host`

Data type: `Optional[Array[Postfix::Type::Lookup::LDAP::Host, 1]]`



Default value: ``undef``

##### <a name="server_port"></a>`server_port`

Data type: `Optional[Bodgitlib::Port]`



Default value: ``undef``

##### <a name="timeout"></a>`timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="query_filter"></a>`query_filter`

Data type: `Optional[Bodgitlib::LDAP::Filter]`



Default value: ``undef``

##### <a name="result_format"></a>`result_format`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="domain"></a>`domain`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="result_attribute"></a>`result_attribute`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="special_result_attribute"></a>`special_result_attribute`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="terminal_result_attribute"></a>`terminal_result_attribute`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="leaf_result_attribute"></a>`leaf_result_attribute`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="scope"></a>`scope`

Data type: `Optional[Bodgitlib::LDAP::Scope]`



Default value: ``undef``

##### <a name="bind"></a>`bind`

Data type: `Optional[Variant[Boolean, Enum['sasl', 'none', 'simple']]]`



Default value: ``undef``

##### <a name="bind_dn"></a>`bind_dn`

Data type: `Optional[Bodgitlib::LDAP::DN]`



Default value: ``undef``

##### <a name="bind_pw"></a>`bind_pw`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="recursion_limit"></a>`recursion_limit`

Data type: `Optional[Integer[1]]`



Default value: ``undef``

##### <a name="expansion_limit"></a>`expansion_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="size_limit"></a>`size_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="dereference"></a>`dereference`

Data type: `Optional[Integer[0, 3]]`



Default value: ``undef``

##### <a name="chase_referrals"></a>`chase_referrals`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="version"></a>`version`

Data type: `Optional[Integer[2, 3]]`



Default value: ``undef``

##### <a name="debuglevel"></a>`debuglevel`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="sasl_mechs"></a>`sasl_mechs`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="sasl_realm"></a>`sasl_realm`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="sasl_authz_id"></a>`sasl_authz_id`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="sasl_minssf"></a>`sasl_minssf`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="start_tls"></a>`start_tls`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="tls_ca_cert_dir"></a>`tls_ca_cert_dir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="tls_ca_cert_file"></a>`tls_ca_cert_file`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="tls_cert"></a>`tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="tls_key"></a>`tls_key`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="tls_require_cert"></a>`tls_require_cert`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="tls_random_file"></a>`tls_random_file`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="tls_cipher_suite"></a>`tls_cipher_suite`

Data type: `Optional[String]`



Default value: ``undef``

### <a name="postfixlookupmemcache"></a>`postfix::lookup::memcache`

Define a Memcache lookup table.

* **Since** 2.0.0

* **See also**
  * puppet_classes::postfix
    * postfix

#### Examples

##### Postscreen temporary whitelist

```puppet
include memcached

class { 'postfix':
  postscreen_cache_map => 'memcache:/etc/postfix/postscreen_cache',
  proxy_write_maps     => ['btree:$data_directory/postscreen_cache'],
  ...
}

postfix::lookup::memcache { '/etc/postfix/postscreen_cache':
  memcache   => ['inet', '127.0.0.1', 11211],
  backup     => 'btree:$data_directory/postscreen_cache',
  key_format => 'postscreen:%s',
  require    => Class['memcached'],
}
```

#### Parameters

The following parameters are available in the `postfix::lookup::memcache` defined type:

* [`ensure`](#ensure)
* [`path`](#path)
* [`memcache`](#memcache)
* [`backup`](#backup)
* [`flags`](#flags)
* [`ttl`](#ttl)
* [`key_format`](#key_format)
* [`domain`](#domain)
* [`data_size_limit`](#data_size_limit)
* [`line_size_limit`](#line_size_limit)
* [`max_try`](#max_try)
* [`retry_pause`](#retry_pause)
* [`timeout`](#timeout)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `'present'`

##### <a name="path"></a>`path`

Data type: `Stdlib::Absolutepath`



Default value: `$title`

##### <a name="memcache"></a>`memcache`

Data type: `Optional[Postfix::Type::Lookup::Memcache::Host]`



Default value: ``undef``

##### <a name="backup"></a>`backup`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="flags"></a>`flags`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ttl"></a>`ttl`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="key_format"></a>`key_format`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="domain"></a>`domain`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="data_size_limit"></a>`data_size_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="line_size_limit"></a>`line_size_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="max_try"></a>`max_try`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="retry_pause"></a>`retry_pause`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="timeout"></a>`timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

### <a name="postfixlookupmysql"></a>`postfix::lookup::mysql`

Define a MySQL lookup table.

* **Since** 1.0.0

* **See also**
  * puppet_classes::postfix
    * postfix

#### Parameters

The following parameters are available in the `postfix::lookup::mysql` defined type:

* [`hosts`](#hosts)
* [`user`](#user)
* [`password`](#password)
* [`dbname`](#dbname)
* [`query`](#query)
* [`ensure`](#ensure)
* [`path`](#path)
* [`result_format`](#result_format)
* [`domain`](#domain)
* [`expansion_limit`](#expansion_limit)
* [`option_file`](#option_file)
* [`option_group`](#option_group)
* [`tls_cert`](#tls_cert)
* [`tls_key`](#tls_key)
* [`tls_ca_cert_file`](#tls_ca_cert_file)
* [`tls_ca_cert_dir`](#tls_ca_cert_dir)
* [`tls_verify_cert`](#tls_verify_cert)

##### <a name="hosts"></a>`hosts`

Data type: `Array[Postfix::Type::Lookup::MySQL::Host, 1]`



##### <a name="user"></a>`user`

Data type: `String`



##### <a name="password"></a>`password`

Data type: `String`



##### <a name="dbname"></a>`dbname`

Data type: `String`



##### <a name="query"></a>`query`

Data type: `String`



##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `'present'`

##### <a name="path"></a>`path`

Data type: `Stdlib::Absolutepath`



Default value: `$title`

##### <a name="result_format"></a>`result_format`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="domain"></a>`domain`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="expansion_limit"></a>`expansion_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="option_file"></a>`option_file`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="option_group"></a>`option_group`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="tls_cert"></a>`tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="tls_key"></a>`tls_key`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="tls_ca_cert_file"></a>`tls_ca_cert_file`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="tls_ca_cert_dir"></a>`tls_ca_cert_dir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="tls_verify_cert"></a>`tls_verify_cert`

Data type: `Optional[Boolean]`



Default value: ``undef``

### <a name="postfixlookuppgsql"></a>`postfix::lookup::pgsql`

Define a PostgreSQL lookup table.

* **Since** 1.0.0

* **See also**
  * puppet_classes::postfix
    * postfix

#### Parameters

The following parameters are available in the `postfix::lookup::pgsql` defined type:

* [`hosts`](#hosts)
* [`user`](#user)
* [`password`](#password)
* [`dbname`](#dbname)
* [`query`](#query)
* [`ensure`](#ensure)
* [`path`](#path)
* [`result_format`](#result_format)
* [`domain`](#domain)
* [`expansion_limit`](#expansion_limit)

##### <a name="hosts"></a>`hosts`

Data type: `Array[Postfix::Type::Lookup::PgSQL::Host, 1]`



##### <a name="user"></a>`user`

Data type: `String`



##### <a name="password"></a>`password`

Data type: `String`



##### <a name="dbname"></a>`dbname`

Data type: `String`



##### <a name="query"></a>`query`

Data type: `String`



##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `'present'`

##### <a name="path"></a>`path`

Data type: `Stdlib::Absolutepath`



Default value: `$title`

##### <a name="result_format"></a>`result_format`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="domain"></a>`domain`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="expansion_limit"></a>`expansion_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

### <a name="postfixlookupsqlite"></a>`postfix::lookup::sqlite`

Define an SQLite lookup table.

* **Since** 1.0.0

* **See also**
  * puppet_classes::postfix
    * postfix

#### Parameters

The following parameters are available in the `postfix::lookup::sqlite` defined type:

* [`dbpath`](#dbpath)
* [`query`](#query)
* [`ensure`](#ensure)
* [`path`](#path)
* [`result_format`](#result_format)
* [`domain`](#domain)
* [`expansion_limit`](#expansion_limit)

##### <a name="dbpath"></a>`dbpath`

Data type: `Stdlib::Absolutepath`



##### <a name="query"></a>`query`

Data type: `String`



##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `'present'`

##### <a name="path"></a>`path`

Data type: `Stdlib::Absolutepath`



Default value: `$title`

##### <a name="result_format"></a>`result_format`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="domain"></a>`domain`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="expansion_limit"></a>`expansion_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

### <a name="postfixmain"></a>`postfix::main`

Define additional Postfix settings.

Any settings not (yet) implemented in the main class or per-transport
settings can be defined here.

* **Since** 1.0.0

* **See also**
  * puppet_classes::postfix
    * postfix
  * puppet_defined_types::postfix::master
    * postfix::master

#### Examples

##### An example setting

```puppet
include postfix
postfix::main { 'dovecot_destination_recipient_limit':
  value => 1,
}
```

#### Parameters

The following parameters are available in the `postfix::main` defined type:

* [`value`](#value)
* [`setting`](#setting)
* [`ensure`](#ensure)

##### <a name="value"></a>`value`

Data type: `String`



##### <a name="setting"></a>`setting`

Data type: `String`



Default value: `$title`

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `'present'`

### <a name="postfixmaster"></a>`postfix::master`

Define additional Postfix services.

* **Since** 1.0.0

* **See also**
  * puppet_classes::postfix
    * postfix
  * puppet_defined_types::postfix::main
    * postfix::main

#### Examples

##### Define the Dovecot LDA service

```puppet
include postfix
postfix::master { 'dovecot/unix':
  chroot       => 'n',
  command      => 'pipe flags=DRhu user=vmail:vmail argv=/path/to/dovecot-lda -f ${sender} -d ${recipient}',
  unprivileged => 'n',
  require      => Class['dovecot'],
}
```

#### Parameters

The following parameters are available in the `postfix::master` defined type:

* [`command`](#command)
* [`service`](#service)
* [`ensure`](#ensure)
* [`private`](#private)
* [`unprivileged`](#unprivileged)
* [`chroot`](#chroot)
* [`wakeup`](#wakeup)
* [`limit`](#limit)

##### <a name="command"></a>`command`

Data type: `String`



##### <a name="service"></a>`service`

Data type: `Pattern[/(?x) ^ [^\/]+ \/ (?:inet|unix(?:-dgram)?|fifo|pass) $/]`



Default value: `$title`

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `'present'`

##### <a name="private"></a>`private`

Data type: `Optional[Enum['-', 'n', 'y']]`



Default value: ``undef``

##### <a name="unprivileged"></a>`unprivileged`

Data type: `Optional[Enum['-', 'n', 'y']]`



Default value: ``undef``

##### <a name="chroot"></a>`chroot`

Data type: `Optional[Enum['-', 'n', 'y']]`



Default value: ``undef``

##### <a name="wakeup"></a>`wakeup`

Data type: `Optional[Pattern[/(?x) ^ (?: - | \d+ [?]? ) $/]]`



Default value: ``undef``

##### <a name="limit"></a>`limit`

Data type: `Optional[Pattern[/(?x) ^ (?: - | \d+ ) $/]]`



Default value: ``undef``

## Resource types

### <a name="postfix_main"></a>`postfix_main`

Manages Postfix settings.

The resource name can be used as a shortcut for specifying the setting
parameter.

#### Properties

The following properties are available in the `postfix_main` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `value`

Value to change the setting to.

If this value is refers to other settings and those settings are also managed
by Puppet, they will be autorequired. If the value can be fully expanded and
matches a file resource that exists in the catalogue then it will be
autorequired. Lookup tables of the form `type:/path/to/file` will use the
filename that is produced by the `postmap(1)` command. For example, a value of
`hash:/etc/aliases` will attempt to autorequire `/etc/aliases.db`. Any setting
that references a service defined in `master.cf` will attempt to autorequire
it. This includes the various `${transport}_delivery_slot_cost`, etc.
settings.

#### Parameters

The following parameters are available in the `postfix_main` type.

* [`name`](#name)
* [`provider`](#provider)
* [`setting`](#setting)
* [`target`](#target)

##### <a name="name"></a>`name`

The name of the setting or a unique string.

##### <a name="provider"></a>`provider`

The specific backend to use for this `postfix_main` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="setting"></a>`setting`

namevar

The name of the setting.

##### <a name="target"></a>`target`

The file in which to store the settings, defaults to
`/etc/postfix/main.cf`.

If a file resource exists in the catalogue for this value it will be
autorequired.

### <a name="postfix_master"></a>`postfix_master`

Manages Postfix services.

The resource name can be used as a shortcut for specifying the service and
type parameters by using the form `<service>/<type>` otherwise it can be left
as a normal string.

#### Properties

The following properties are available in the `postfix_master` type.

##### `chroot`

Valid values: `-`, `n`, `y`

Whether the service runs chrooted.

Default value: `-`

##### `command`

The command name and arguments.

The command to run. If the command includes any `-o` options then these
follow the same autorequire rules as for
[`postfix_main`](#native-type-postfix_main) resources with the exception that
it doesn\'t autorequire a setting that is redefined with `-o` in the same
command.

If the command uses `pipe(8)` then the value from the `user=` attribute is
parsed and any existing user or group resource will be autorequired.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `limit`

Valid values: `-`, `%r{^\d+$}`

Process limit.

Default value: `-`

##### `private`

Valid values: `-`, `n`, `y`

Whether or not access is restricted.

Default value: `-`

##### `unprivileged`

Valid values: `-`, `n`, `y`

Whether the service runs with root privileges or not.

Default value: `-`

##### `wakeup`

Valid values: `-`, `%r{^\d+[?]?$}`

Wake up time.

Default value: `-`

#### Parameters

The following parameters are available in the `postfix_master` type.

* [`name`](#name)
* [`provider`](#provider)
* [`service`](#service)
* [`target`](#target)
* [`type`](#type)

##### <a name="name"></a>`name`

The name of the service and type separated by `/`, or a unique
string.

##### <a name="provider"></a>`provider`

The specific backend to use for this `postfix_master` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="service"></a>`service`

namevar

The service name.

##### <a name="target"></a>`target`

The file in which to store the services, defaults to
`/etc/postfix/master.cf`.

If a file resource exists in the catalogue for this value it will be
autorequired.

##### <a name="type"></a>`type`

Valid values: `inet`, `unix`, `unix-dgram`, `fifo`, `pass`

namevar

The service type.

## Functions

### <a name="postfixflatten_host"></a>`postfix::flatten_host`

Type: Puppet Language

Flatten a host structure to a string.

#### Examples

##### 

```puppet
postfix::flatten_host('2001:db8::1')
postfix::flatten_host(['192.0.2.1', 389])
```

#### `postfix::flatten_host(Optional[Variant[Postfix::Type::Lookup::LDAP::Host, Postfix::Type::Lookup::MySQL::Host, Postfix::Type::Lookup::PgSQL::Host, Postfix::Type::Lookup::Memcache::Host]] $host)`

Flatten a host structure to a string.

Returns: `Optional[String]` The flattened string.

##### Examples

###### 

```puppet
postfix::flatten_host('2001:db8::1')
postfix::flatten_host(['192.0.2.1', 389])
```

##### `host`

Data type: `Optional[Variant[Postfix::Type::Lookup::LDAP::Host, Postfix::Type::Lookup::MySQL::Host, Postfix::Type::Lookup::PgSQL::Host, Postfix::Type::Lookup::Memcache::Host]]`

The host to flatten, `undef` is passed through.

### <a name="postfixflatten_hosts"></a>`postfix::flatten_hosts`

Type: Puppet Language

Flatten an array of host structures to an array of strings.

#### Examples

##### 

```puppet
postfix::flatten_hosts(['2001:db8::1', ['192.0.2.1', 389]])
```

#### `postfix::flatten_hosts(Optional[Array[Variant[Postfix::Type::Lookup::LDAP::Host, Postfix::Type::Lookup::MySQL::Host, Postfix::Type::Lookup::PgSQL::Host], 1]] $hosts)`

Flatten an array of host structures to an array of strings.

Returns: `Optional[Array[String, 1]]` The array of flattened strings.

##### Examples

###### 

```puppet
postfix::flatten_hosts(['2001:db8::1', ['192.0.2.1', 389]])
```

##### `hosts`

Data type: `Optional[Array[Variant[Postfix::Type::Lookup::LDAP::Host, Postfix::Type::Lookup::MySQL::Host, Postfix::Type::Lookup::PgSQL::Host], 1]]`

The array of hosts to flatten, `undef` is passed through.

## Data types

### <a name="postfixtypelookup"></a>`Postfix::Type::Lookup`

The Postfix::Type::Lookup data type.

* **Since** 2.0.0

Alias of

```puppet
Variant[Postfix::Type::Lookup::Database, Enum['ldap', 'memcache', 'mysql', 'pgsql', 'sqlite']]
```

### <a name="postfixtypelookupdatabase"></a>`Postfix::Type::Lookup::Database`

The Postfix::Type::Lookup::Database data type.

* **Since** 2.0.0

Alias of

```puppet
Variant[Postfix::Type::Lookup::Database::Hashed, Postfix::Type::Lookup::Database::Flat]
```

### <a name="postfixtypelookupdatabaseflat"></a>`Postfix::Type::Lookup::Database::Flat`

The Postfix::Type::Lookup::Database::Flat data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['texthash', 'cidr', 'pcre', 'regexp']
```

### <a name="postfixtypelookupdatabasehashed"></a>`Postfix::Type::Lookup::Database::Hashed`

The Postfix::Type::Lookup::Database::Hashed data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['btree', 'cdb', 'dbm', 'sdbm', 'hash', 'lmdb']
```

### <a name="postfixtypelookupldaphost"></a>`Postfix::Type::Lookup::LDAP::Host`

The Postfix::Type::Lookup::LDAP::Host data type.

* **Since** 2.0.0

Alias of

```puppet
Variant[Bodgitlib::Host, Tuple[Bodgitlib::Host, Bodgitlib::Port], Bodgitlib::LDAP::URI::Simple]
```

### <a name="postfixtypelookupmemcachehost"></a>`Postfix::Type::Lookup::Memcache::Host`

The Postfix::Type::Lookup::Memcache::Host data type.

* **Since** 2.0.0

Alias of

```puppet
Postfix::Type::Lookup::MySQL::Host
```

### <a name="postfixtypelookupmysqlhost"></a>`Postfix::Type::Lookup::MySQL::Host`

The Postfix::Type::Lookup::MySQL::Host data type.

* **Since** 2.0.0

Alias of

```puppet
Variant[Tuple[Enum['unix'], Stdlib::Absolutepath], Tuple[Enum['inet'], Bodgitlib::Host, Bodgitlib::Port, 2, 3], Tuple[Bodgitlib::Host, Bodgitlib::Port], Bodgitlib::Host]
```

### <a name="postfixtypelookuppgsqlhost"></a>`Postfix::Type::Lookup::PgSQL::Host`

The Postfix::Type::Lookup::PgSQL::Host data type.

* **Since** 2.0.0

Alias of

```puppet
Postfix::Type::Lookup::MySQL::Host
```

